@@ -219,6 +219,8 @@ public:
     int paintAttributes;
 
     QwtGuardedPainter guardedPainter;
+
+	QRect canvasRect; // temporary, while painting
 };
 
 //! Constructor
@@ -515,9 +517,11 @@ QwtDoubleRect QwtPlotCurve::boundingRect() const
 */
 void QwtPlotCurve::draw(QPainter *painter,
     const QwtScaleMap &xMap, const QwtScaleMap &yMap,
-    const QRect &) const
+	const QRect &canvasRect) const
 {
-    draw(painter, xMap, yMap, 0, -1);
+	d_data->canvasRect = canvasRect;
+	draw(painter, xMap, yMap, 0, -1);
+	d_data->canvasRect = QRect();
 }
 
 /*!
@@ -814,8 +818,8 @@ void QwtPlotCurve::drawLines(QPainter *painter,
         }
     }
 
-    if ( d_data->paintAttributes & ClipPolygons )
-        polyline = QwtClipper::clipPolygonF(painter->window(), polyline);
+	if ( d_data->canvasRect.isValid() && d_data->paintAttributes & ClipPolygons )
+		polyline = QwtClipper::clipPolygonF(d_data->canvasRect, polyline);
 
     QwtPainter::drawPolyline(painter, polyline);
 
@@ -868,10 +872,6 @@ void QwtPlotCurve::drawDots(QPainter *painter,
     const QwtScaleMap &xMap, const QwtScaleMap &yMap,
     int from, int to) const
 {
-    const QRect window = painter->window();
-    if ( window.isEmpty() )
-        return;
-
     const bool doFill = d_data->brush.style() != Qt::NoBrush;
 
     QwtPolygonF polyline;
@@ -880,7 +880,7 @@ void QwtPlotCurve::drawDots(QPainter *painter,
 
     if ( to > from && d_data->paintAttributes & PaintFiltered )
     {
-        if ( doFill )
+		if ( doFill || d_data->canvasRect.isEmpty() )
         {
             QPointF pp( xMap.xTransform(x(from)), yMap.xTransform(y(from)) );
 
@@ -909,7 +909,7 @@ void QwtPlotCurve::drawDots(QPainter *painter,
             // if we don't need to fill, we can sort out
             // duplicates independent from the order
 
-            PrivateData::PixelMatrix pixelMatrix(window);
+			PrivateData::PixelMatrix pixelMatrix(d_data->canvasRect);
 
             for (int i = from; i <= to; i++)
             {
@@ -935,8 +935,8 @@ void QwtPlotCurve::drawDots(QPainter *painter,
 
     if ( doFill )
     {
-        if ( d_data->paintAttributes & ClipPolygons )
-            polyline = QwtClipper::clipPolygonF(painter->window(), polyline);
+		if ( d_data->canvasRect.isValid() && (d_data->paintAttributes & ClipPolygons) )
+			polyline = QwtClipper::clipPolygonF(d_data->canvasRect, polyline);
 
         fillCurve(painter, xMap, yMap, polyline);
     }
@@ -983,8 +983,8 @@ void QwtPlotCurve::drawSteps(QPainter *painter,
         polyline[ip] = QPointF(xi, yi);
     }
 
-    if ( d_data->paintAttributes & ClipPolygons )
-        polyline = QwtClipper::clipPolygonF(painter->window(), polyline);
+	if ( d_data->canvasRect.isValid() && (d_data->paintAttributes & ClipPolygons) )
+		polyline = QwtClipper::clipPolygonF(d_data->canvasRect, polyline);
 
     QwtPainter::drawPolyline(painter, polyline);
 
@@ -1131,8 +1131,8 @@ void QwtPlotCurve::closePolyline(
     }
     else
     {
-        pa[sz] = QPointF(pa[sz - 1].x(), yMap.transform(d_data->reference));
-        pa[pa.size() - 1] = QPointF(pa[0].x(), yMap.transform(d_data->reference));
+		pa[sz] = QPointF(pa[sz - 1].x(), yMap.transform(d_data->reference));
+		pa[pa.size() - 1] = QPointF(pa[0].x(), yMap.transform(d_data->reference));
     }
 }
 
@@ -1159,13 +1159,10 @@ void QwtPlotCurve::drawSymbols(QPainter *painter, const QwtSymbol &symbol,
     QRect rect;
     rect.setSize(metricsMap.screenToLayout(symbol.size()));
 
-    if ( to > from && d_data->paintAttributes & PaintFiltered )
+	if ( (to > from) && (d_data->paintAttributes & PaintFiltered) &&
+		 d_data->canvasRect.isValid() )
     {
-        const QRect window = painter->window();
-        if ( window.isEmpty() )
-            return;
-
-        PrivateData::PixelMatrix pixelMatrix(window);
+		PrivateData::PixelMatrix pixelMatrix(d_data->canvasRect);
 
         for (int i = from; i <= to; i++)
         {
