@@ -2,8 +2,8 @@
     File                 : fitclasses.h
     Project              : QtiPlot
     --------------------------------------------------------------------
-    Copyright            : (C) 2006 by Ion Vasilief, Tilman Hoener zu Siederdissen
-    Email (use @ for *)  : ion_vasilief*yahoo.fr, thzs*gmx.net
+    Copyright            : (C) 2006 by Ion Vasilief
+    Email (use @ for *)  : ion_vasilief*yahoo.fr
     Description          : Exponential fit classes
 
  ***************************************************************************/
@@ -36,13 +36,15 @@ class ExponentialFit : public Fit
 	Q_OBJECT
 
 	public:
+		ExponentialFit(ApplicationWindow *parent, QwtPlotCurve *c, bool expGrowth = false);
+		ExponentialFit(ApplicationWindow *parent, QwtPlotCurve *c, double start, double end, bool expGrowth = false);
 		ExponentialFit(ApplicationWindow *parent, Graph *g,  bool expGrowth = false);
 		ExponentialFit(ApplicationWindow *parent, Graph *g, const QString& curveTitle, bool expGrowth = false);
 		ExponentialFit(ApplicationWindow *parent, Graph *g, const QString& curveTitle,
 				double start, double end, bool expGrowth = false);
 		ExponentialFit(ApplicationWindow *parent, Table *t, const QString& xCol, const QString& yCol, int startRow = 1, int endRow = -1, bool expGrowth = false);
 
-        double eval(double *par, double x){return par[0]*exp(-par[1]*x) + par[2];};
+        double eval(double *par, double x){return par[0]*exp(-x/par[1]) + par[2];};
 		bool isExponentialGrowth(){return is_exp_growth;};
 
 	private:
@@ -58,16 +60,17 @@ class TwoExpFit : public Fit
 	Q_OBJECT
 
 	public:
+	    TwoExpFit(ApplicationWindow *parent, QwtPlotCurve *c);
+	    TwoExpFit(ApplicationWindow *parent, QwtPlotCurve *c, double start, double end);
 		TwoExpFit(ApplicationWindow *parent, Graph *g);
 		TwoExpFit(ApplicationWindow *parent, Graph *g, const QString& curveTitle);
 		TwoExpFit(ApplicationWindow *parent, Graph *g, const QString& curveTitle, double start, double end);
 		TwoExpFit(ApplicationWindow *parent, Table *t, const QString& xCol, const QString& yCol, int startRow = 1, int endRow = -1);
 
-        double eval(double *par, double x){return par[0]*exp(-par[1]*x)+par[2]*exp(-par[3]*x)+par[4];};
+        double eval(double *par, double x){return par[0]*exp(-x/par[1]) + par[2]*exp(-x/par[3]) + par[4];};
 
 	private:
 		void init();
-		void customizeFitResults();
 		void calculateFitCurveData(double *X, double *Y);
 };
 
@@ -76,16 +79,17 @@ class ThreeExpFit : public Fit
 	Q_OBJECT
 
 	public:
+		ThreeExpFit(ApplicationWindow *parent, QwtPlotCurve *c);
+	    ThreeExpFit(ApplicationWindow *parent, QwtPlotCurve *c, double start, double end);
 		ThreeExpFit(ApplicationWindow *parent, Graph *g);
 		ThreeExpFit(ApplicationWindow *parent, Graph *g, const QString& curveTitle);
 		ThreeExpFit(ApplicationWindow *parent, Graph *g, const QString& curveTitle, double start, double end);
 		ThreeExpFit(ApplicationWindow *parent, Table *t, const QString& xCol, const QString& yCol, int startRow = 1, int endRow = -1);
 
-        double eval(double *par, double x){return par[0]*exp(-x*par[1])+par[2]*exp(-x*par[3])+par[4]*exp(-x*par[5])+par[6];};
+        double eval(double *par, double x){return par[0]*exp(-x/par[1]) + par[2]*exp(-x/par[3]) + par[4]*exp(-x/par[5]) + par[6];};
 
 	private:
 		void init();
-		void customizeFitResults();
 		void calculateFitCurveData(double *X, double *Y);
 };
 #endif
