@@ -228,7 +228,7 @@ void MultiPeakFit::insertPeakFunctionCurve(int peak)
 	QString title = tr("Peak") + QString::number(++index);
 
 	FunctionCurve *c = new FunctionCurve(FunctionCurve::Normal, title);
-	c->setPen(QPen(ColorBox::color(d_peaks_color), 1));
+	c->setPen(QPen(d_peaks_color, 1));
 	c->setRange(d_from, d_to);
 	c->setFormula("y0 + " + peakFormula(peak + 1, d_profile));
 	c->setConstant(d_param_names[d_p - 1], d_results[d_p - 1]);//y0 - offset
@@ -236,6 +236,10 @@ void MultiPeakFit::insertPeakFunctionCurve(int peak)
 		int p = 3*peak + j;
 		c->setConstant(d_param_names[p], d_results[p]);
 	}
+	if (d_curve){
+		c->setCurveType(d_curve->curveType());
+		c->setAxis(d_curve->xAxis(), d_curve->yAxis());
+	}
 	c->loadData(d_points);
 
 	d_output_graph->insertPlotItem(c, Graph::Line);
@@ -279,11 +283,17 @@ void MultiPeakFit::generateFitCurve()
 			return;
 		}
 
-		#ifdef Q_CC_MSVC
-			QVarLengthArray<double> X(d_points), Y(d_points);
-		#else
-			double X[d_points], Y[d_points];
-		#endif
+		double *X = (double *)malloc(d_points*sizeof(double));
+		if (!X){
+			memoryErrorMessage();
+			return;
+		}
+		double *Y = (double *)malloc(d_points*sizeof(double));
+		if (!Y){
+			memoryErrorMessage();
+			free(X);
+			return;
+		}
 
 		QString tableName = app->generateUniqueName(tr("Fit"));
 		QString dataSet;
@@ -333,15 +343,20 @@ void MultiPeakFit::generateFitCurve()
 
 			label = tableName + "_2";
 			DataCurve *c = new DataCurve(d_result_table, tableName + "_1", label);
+			if (d_curve){
+				c->setCurveType(d_curve->curveType());
+				c->setAxis(d_curve->xAxis(), d_curve->yAxis());
+			}
 			if (d_peaks > 1)
-				c->setPen(QPen(ColorBox::color(d_curveColorIndex), 2));
+				c->setPen(QPen(d_curveColor, 2));
 			else
-				c->setPen(QPen(ColorBox::color(d_curveColorIndex), 1));
-#ifdef Q_CC_MSVC
-			c->setData(X.data(), Y.data(), d_points);
-#else
-			c->setData(X, Y, d_points);
-#endif
+				c->setPen(QPen(d_curveColor, 1));
+
+			if (c->curveType() == QwtPlotCurve::Xfy)
+				c->setData(Y, X, d_points);
+			else
+				c->setData(X, Y, d_points);
+
 			d_output_graph->insertPlotItem(c, Graph::Line);
 			d_output_graph->addFitCurve(c);
 
@@ -352,12 +367,18 @@ void MultiPeakFit::generateFitCurve()
 
 					label = tableName + "_" + tr("peak") + QString::number(i+1);
 					c = new DataCurve(d_result_table, tableName + "_1", label);
-					c->setPen(QPen(ColorBox::color(d_peaks_color), 1));
-#ifdef Q_CC_MSVC
-					c->setData(X.data(), Y.data(), d_points);
-#else
-					c->setData(X, Y, d_points);
-#endif
+					c->setPen(QPen(d_peaks_color, 1));
+
+					if (d_curve){
+						c->setCurveType(d_curve->curveType());
+						c->setAxis(d_curve->xAxis(), d_curve->yAxis());
+					}
+
+					if (c->curveType() == QwtPlotCurve::Xfy)
+						c->setData(Y, X, d_points);
+					else
+						c->setData(X, Y, d_points);
+
 					d_output_graph->insertPlotItem(c, Graph::Line);
 					d_output_graph->addFitCurve(c);
 				}
@@ -365,6 +386,8 @@ void MultiPeakFit::generateFitCurve()
 			d_output_graph->replot();
 		}
 		gsl_matrix_free(m);
+		free(X);
+		free(Y);
 	}
 }
 
@@ -415,6 +438,11 @@ QString MultiPeakFit::logFitInfo(int iterations, int status)
 	return info;
 }
 
+void MultiPeakFit::setPeakCurvesColor(int colorIndex)
+{
+	d_peaks_color = ColorBox::defaultColor(colorIndex);
+}
+
 /*****************************************************************************
  *
  * Class LorentzFit
