@@ -90,32 +90,20 @@ bool PluginFit::load(const QString& pluginName)
 	lib.setAutoUnload(false);
 
 	d_fsimplex = (fit_function_simplex) lib.resolve( "function_d" );
-	if (!d_fsimplex){
-		QMessageBox::critical((ApplicationWindow *)parent(), tr("QtiPlot - Plugin Error"),
-				tr("The plugin does not implement a %1 method necessary for simplex fitting.").arg("function_d"));
+	if (!d_fsimplex)
 		return false;
-	}
 
 	d_f = (fit_function) lib.resolve( "function_f" );
-	if (!d_f){
-		QMessageBox::critical((ApplicationWindow *)parent(), tr("QtiPlot - Plugin Error"),
-				tr("The plugin does not implement a %1 method necessary for Levenberg-Marquardt fitting.").arg("function_f"));
+	if (!d_f)
 		return false;
-	}
 
 	d_df = (fit_function_df) lib.resolve( "function_df" );
-	if (!d_df){
-		QMessageBox::critical((ApplicationWindow *)parent(), tr("QtiPlot - Plugin Error"),
-				tr("The plugin does not implement a %1 method necessary for Levenberg-Marquardt fitting.").arg("function_df"));
+	if (!d_df)
 		return false;
-	}
 
 	d_fdf = (fit_function_fdf) lib.resolve( "function_fdf" );
-	if (!d_fdf){
-		QMessageBox::critical((ApplicationWindow *)parent(), tr("QtiPlot - Plugin Error"),
-				tr("The plugin does not implement a %1 method necessary for Levenberg-Marquardt fitting.").arg("function_fdf"));
+	if (!d_fdf)
 		return false;
-	}
 
 	f_eval = (fitFunctionEval) lib.resolve("function_eval");
 	if (!f_eval)
