@@ -28,7 +28,6 @@
  ***************************************************************************/
 #include "FFTDialog.h"
 #include <FFT.h>
-#include <fft2D.h>
 #include <ApplicationWindow.h>
 #include <Table.h>
 #include <Graph.h>
@@ -36,6 +35,7 @@
 #include <MultiLayer.h>
 #include <Matrix.h>
 #include <DoubleSpinBox.h>
+#include <fft2D.h>
 
 #include <QRadioButton>
 #include <QGroupBox>
@@ -55,7 +55,6 @@ FFTDialog::FFTDialog(int type, QWidget* parent, Qt::WFlags fl )
 	setSizeGripEnabled( true );
 	setAttribute(Qt::WA_DeleteOnClose);
 
-	d_matrix = 0;
 	d_table = 0;
 	graph = 0;
 	d_type = type;
@@ -73,6 +72,7 @@ FFTDialog::FFTDialog(int type, QWidget* parent, Qt::WFlags fl )
 	gb1->setLayout(hbox1);
 
 	QGridLayout *gl1 = new QGridLayout();
+	gl1->setColumnStretch(1, 1);
 	if (d_type == onGraph)
 		gl1->addWidget(new QLabel(tr("Curve")), 0, 0);
 	else if (d_type == onTable)
@@ -80,17 +80,16 @@ FFTDialog::FFTDialog(int type, QWidget* parent, Qt::WFlags fl )
 
 	if (d_type != onMatrix){
 		boxName = new QComboBox();
-		if (d_type == onTable)
-			connect(boxName, SIGNAL(activated(const QString&)), this, SLOT(activateCurve(const QString&)));
-		else if (d_type == onGraph)
-			connect(boxName, SIGNAL(activated(int)), this, SLOT(activateCurve(int)));
+		connect(boxName, SIGNAL(activated(const QString&)), this, SLOT(activateDataSet(const QString&)));
 		gl1->addWidget(boxName, 0, 1);
 		setFocusProxy(boxName);
 	}
 
+	ApplicationWindow *app = (ApplicationWindow *)parent;
+
 	boxSampling = new DoubleSpinBox();
-	boxSampling->setDecimals(((ApplicationWindow *)parent)->d_decimal_digits);
-	boxSampling->setLocale(((ApplicationWindow *)parent)->locale());
+	boxSampling->setDecimals(app->d_decimal_digits);
+	boxSampling->setLocale(app->locale());
 
 	if (d_type == onTable || d_type == onMatrix){
 		gl1->addWidget(new QLabel(tr("Real")), 1, 0);
@@ -104,7 +103,8 @@ FFTDialog::FFTDialog(int type, QWidget* parent, Qt::WFlags fl )
 		if (d_type == onTable){
 			gl1->addWidget(new QLabel(tr("Sampling Interval")), 3, 0);
 			gl1->addWidget(boxSampling, 3, 1);
-		}
+		} else
+			connect(boxReal, SIGNAL(activated(const QString&)), this, SLOT(activateDataSet(const QString&)));
 	} else if (d_type == onGraph){
 		gl1->addWidget(new QLabel(tr("Sampling Interval")), 1, 0);
 		gl1->addWidget(boxSampling, 1, 1);
@@ -114,19 +114,24 @@ FFTDialog::FFTDialog(int type, QWidget* parent, Qt::WFlags fl )
 	gb2->setLayout(gl1);
 
 	boxNormalize = new QCheckBox(tr( "&Normalize Amplitude" ));
-	boxNormalize->setChecked(true);
+	boxNormalize->setChecked(app->d_fft_norm_amp);
 
-	if (d_type != onMatrix){
-		boxOrder = new QCheckBox(tr( "&Shift Results" ));
-		boxOrder->setChecked(true);
+	boxOrder = new QCheckBox(tr( "&Shift Results" ));
+	boxOrder->setChecked(app->d_fft_shift_res);
+
+	if (d_type == onMatrix){
+		boxPower2 = new QCheckBox(tr( "&Zero pad to nearest power of 2 size" ));
+		boxPower2->setChecked(app->d_fft_power2);
+		boxPower2->hide();
 	}
 
 	QVBoxLayout *vbox1 = new QVBoxLayout();
 	vbox1->addWidget(gb1);
 	vbox1->addWidget(gb2);
 	vbox1->addWidget(boxNormalize);
-	if (d_type != onMatrix)
-		vbox1->addWidget(boxOrder);
+	vbox1->addWidget(boxOrder);
+	if (d_type == onMatrix)
+		vbox1->addWidget(boxPower2);
 	vbox1->addStretch();
 
 	buttonOK = new QPushButton(tr("&OK"));
@@ -143,8 +148,24 @@ FFTDialog::FFTDialog(int type, QWidget* parent, Qt::WFlags fl )
 	hbox2->addLayout(vbox2);
 
 	// signals and slots connections
-	connect( buttonOK, SIGNAL( clicked() ), this, SLOT( accept() ) );
-	connect( buttonCancel, SIGNAL( clicked() ), this, SLOT( close() ) );
+	connect(buttonOK, SIGNAL(clicked()), this, SLOT(accept()));
+	connect(buttonCancel, SIGNAL(clicked()), this, SLOT(close()));
+	if (d_type == onMatrix){
+		updateShiftLabel();
+		connect(forwardBtn, SIGNAL(toggled(bool)), this, SLOT(updateShiftLabel()));
+		connect(backwardBtn, SIGNAL(toggled(bool)), this, SLOT(updateShiftLabel()));
+	}
+}
+
+void FFTDialog::updateShiftLabel()
+{
+	if (d_type != onMatrix)
+		return;
+
+	if (forwardBtn->isChecked())
+		boxOrder->setText(tr("DC &Shift Center"));
+	else
+		boxOrder->setText(tr("Undo &Shift"));
 }
 
 void FFTDialog::accept()
@@ -157,9 +178,10 @@ void FFTDialog::accept()
 
 	ApplicationWindow *app = (ApplicationWindow *)parent();
     FFT *fft = NULL;
-	if (graph)
-		fft = new FFT(app, graph->curve(boxName->currentIndex()));
-	else if (d_table){
+	if (graph){
+		QString name = boxName->currentText();
+		fft = new FFT(app, graph->curve(name.left(name.indexOf(" ["))));
+	} else if (d_table){
 		if (boxReal->currentText().isEmpty()){
 			QMessageBox::critical(this, tr("QtiPlot - Error"), tr("Please choose a column for the real part of the data!"));
 			boxReal->setFocus();
@@ -183,27 +205,27 @@ void FFTDialog::setGraph(Graph *g)
 
 	graph = g;
 	boxName->insertStringList(g->analysableCurvesList());
-	activateCurve(boxName->currentIndex());
+	activateDataSet(boxName->currentText());
 }
 
-void FFTDialog::activateCurve(int curveIndex)
+void FFTDialog::activateDataSet(const QString& s)
 {
-	if (!graph)
-		return;
-
-	PlotCurve *c = graph->curve(curveIndex);
-	if (!c)
-		return;
-	boxSampling->setValue(c->x(1) - c->x(0));
-}
-
-void FFTDialog::activateCurve(const QString& curveName)
-{
-	if (!d_table)
-		return;
-
-	int col = d_table->colIndex(curveName);
-	boxSampling->setValue(d_table->cell(1, col) - d_table->cell(0, col));
+	if (d_type == onMatrix){
+		ApplicationWindow *app = (ApplicationWindow *)parent();
+		if (app){
+			Matrix *m = app->matrix(s);
+			if (m)
+				boxPower2->setVisible(!isPower2(m->numRows()) || !isPower2(m->numCols()));
+		}
+	} else if (d_table){
+		int col = d_table->colIndex(s);
+		boxSampling->setValue(d_table->cell(1, col) - d_table->cell(0, col));
+	} else if (graph){
+		PlotCurve *c = graph->curve(s.left(s.indexOf(" [")));
+		if (!c)
+			return;
+		boxSampling->setValue(c->x(1) - c->x(0));
+	}
 }
 
 void FFTDialog::setTable(Table *t)
@@ -239,132 +261,43 @@ void FFTDialog::setTable(Table *t)
 
 void FFTDialog::setMatrix(Matrix *m)
 {
-    ApplicationWindow *app = (ApplicationWindow *)parent();
-    QStringList lst = app->matrixNames();
-    boxReal->addItems(lst);
-    if (m){
-        boxReal->setCurrentIndex(lst.indexOf(m->objectName()));
-        d_matrix = m;
-    }
-    boxImaginary->addItem (" ");
-    boxImaginary->addItems(lst);
+	ApplicationWindow *app = (ApplicationWindow *)parent();
+	QStringList lst = app->matrixNames();
+	boxReal->addItems(lst);
+	if (m){
+		boxReal->setCurrentIndex(lst.indexOf(m->objectName()));
+		d_type = onMatrix;
+		boxPower2->setVisible(!isPower2(m->numRows()) || !isPower2(m->numCols()));
+	}
+	boxImaginary->addItem (" ");
+	boxImaginary->addItems(lst);
 }
 
 void FFTDialog::fftMatrix()
 {
-    ApplicationWindow *app = (ApplicationWindow *)parent();
-    Matrix *mReal = app->matrix(boxReal->currentText());
-    if (!mReal)
-        return;
-
-    bool inverse = backwardBtn->isChecked();
-    int width = mReal->numCols();
-    int height = mReal->numRows();
-
-    bool errors = false;
-    Matrix *mIm = app->matrix(boxImaginary->currentText());
-    if (!mIm)
-        errors = true;
-    else if (mIm && (mIm->numCols() != width || mIm->numRows() != height)){
-        errors = true;
-        QMessageBox::warning(app, tr("QtiPlot"),
-        tr("The two matrices have different dimensions, the imaginary part will be neglected!"));
-    }
-
-    double **x_int_re = Matrix::allocateMatrixData(height, width); /* real coeff matrix */
-    if (!x_int_re)
+	ApplicationWindow *app = (ApplicationWindow *)parent();
+	if (!app)
 		return;
-    double **x_int_im = Matrix::allocateMatrixData(height, width); /* imaginary coeff  matrix*/
-	if (!x_int_im){
-	    Matrix::freeMatrixData(x_int_re, height);
+
+	Matrix *mReal = app->matrix(boxReal->currentText());
+	if (!mReal)
 		return;
+
+	FFT *fft = new FFT(app, mReal, app->matrix(boxImaginary->currentText()), backwardBtn->isChecked(),
+					boxOrder->isChecked(), boxNormalize->isChecked(), boxPower2->isChecked());
+	fft->run();
+	delete fft;
+}
+
+void FFTDialog::closeEvent (QCloseEvent * e)
+{
+	ApplicationWindow *app = (ApplicationWindow *)parent();
+	if (app){
+		app->d_fft_norm_amp = boxNormalize->isChecked();
+		app->d_fft_shift_res = boxOrder->isChecked();
+		if (d_type == onMatrix)
+			app->d_fft_power2 = boxPower2->isChecked();
 	}
 
-	QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-
-    for (int i = 0; i < height; i++){
-        for (int j = 0; j < width; j++){
-            x_int_re[i][j] = mReal->cell(i, j);
-            if (errors)
-                x_int_im[i][j] = 0.0;
-            else
-                x_int_im[i][j] = mIm->cell(i, j);
-        }
-    }
-
-    double **x_fin_re = NULL, **x_fin_im = NULL;
-    if (inverse){
-        x_fin_re = Matrix::allocateMatrixData(height, width); // coeff of the initial image
-        x_fin_im = Matrix::allocateMatrixData(height, width); // filled with 0 if everythng OK
-		if (!x_fin_re || !x_fin_im){
-		    Matrix::freeMatrixData(x_int_re, height);
-		    Matrix::freeMatrixData(x_int_im, height);
-			QApplication::restoreOverrideCursor();
-			return;
-		}
-
-        fft2d_inv(x_int_re, x_int_im, x_fin_re, x_fin_im, width, height);
-    } else
-        fft2d(x_int_re, x_int_im, width, height);
-
-    Matrix *realCoeffMatrix = app->newMatrix(height, width);
-    QString realCoeffMatrixName = app->generateUniqueName(tr("RealMatrixFFT"));
-    app->setWindowName(realCoeffMatrix, realCoeffMatrixName);
-    realCoeffMatrix->setWindowLabel(tr("Real part of the FFT transform of") + " " + mReal->objectName());
-
-    Matrix *imagCoeffMatrix = app->newMatrix(height, width);
-    QString imagCoeffMatrixName = app->generateUniqueName(tr("ImagMatrixFFT"));
-    app->setWindowName(imagCoeffMatrix, imagCoeffMatrixName);
-    imagCoeffMatrix->setWindowLabel(tr("Imaginary part of the FFT transform of") + " " + mReal->objectName());
-
-    Matrix *ampMatrix = app->newMatrix(height, width);
-    QString ampMatrixName = app->generateUniqueName(tr("AmplitudeMatrixFFT"));
-    app->setWindowName(ampMatrix, ampMatrixName);
-    ampMatrix->setWindowLabel(tr("Amplitudes of the FFT transform of") + " " + mReal->objectName());
-
-    if (inverse){
-        for (int i = 0; i < height; i++){
-            for (int j = 0; j < width; j++){
-                double re = x_fin_re[i][j];
-                double im = x_fin_im[i][j];
-                realCoeffMatrix->setCell(i, j, re);
-                imagCoeffMatrix->setCell(i, j, im);
-                ampMatrix->setCell(i, j, sqrt(re*re + im*im));
-            }
-        }
-        Matrix::freeMatrixData(x_fin_re, height);
-        Matrix::freeMatrixData(x_fin_im, height);
-    } else {
-        for (int i = 0; i < height; i++){
-            for (int j = 0; j < width; j++){
-                double re = x_int_re[i][j];
-                double im = x_int_im[i][j];
-                realCoeffMatrix->setCell(i, j, re);
-                imagCoeffMatrix->setCell(i, j, im);
-                ampMatrix->setCell(i, j, sqrt(re*re + im*im));
-            }
-        }
-    }
-
-    if (boxNormalize->isChecked()){
-        double amp_min, amp_max;
-        ampMatrix->range(&amp_min, &amp_max);
-        for (int i = 0; i < height; i++){
-            for (int j = 0; j < width; j++){
-                double amp = ampMatrix->cell(i, j);
-                ampMatrix->setCell(i, j, amp/amp_max);
-            }
-        }
-    }
-
-    if (d_matrix){
-        realCoeffMatrix->resize(d_matrix->size());
-        imagCoeffMatrix->resize(d_matrix->size());
-        ampMatrix->resize(d_matrix->size());
-    }
-    ampMatrix->setViewType(Matrix::ImageView);
-
-    Matrix::freeMatrixData(x_int_re, height);
-    Matrix::freeMatrixData(x_int_im, height);
-    QApplication::restoreOverrideCursor();
+	e->accept();
 }
