@@ -1,3 +1,35 @@
+/***************************************************************************
+   File                 : fit_gsl.cpp
+   Project              : QtiPlot
+   Description          : Built-in data fit models for QtiPlot
+   --------------------------------------------------------------------
+   Copyright            : (C) 2004-2010 Ion Vasilief (ion_vasilief*yahoo.fr)
+						  (replace * with @ in the email address)
+ ***************************************************************************/
+
+/***************************************************************************
+ *                                                                         *
+ *  This program is free software; you can redistribute it and/or modify   *
+ *  it under the terms of the GNU General Public License as published by   *
+ *  the Free Software Foundation; either version 2 of the License, or      *
+ *  (at your option) any later version.                                    *
+ *                                                                         *
+ *  As a special exception, you may omit the above copyright notice when   *
+ *  distributing modified copies of this file (for instance, when using it *
+ *  as a template for your own fit plugin).                                *
+ *                                                                         *
+ *  This program is distributed in the hope that it will be useful,        *
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
+ *  GNU General Public License for more details.                           *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the Free Software           *
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
+ *   Boston, MA  02110-1301  USA                                           *
+ *                                                                         *
+ ***************************************************************************/
+
 #include "fit_gsl.h"
 #include <MyParser.h>
 #include "NonLinearFit.h"
