@@ -47,6 +47,7 @@ class QSpinBox;
 class QLabel;
 class QRadioButton;
 class QListWidget;
+class QSlider;
 class ColorButton;
 class DoubleSpinBox;
 class QFontComboBox;
@@ -219,7 +220,7 @@ private:
 	QLabel *lblScriptingLanguage, *lblInitWindow;
 	QComboBox *boxScriptingLanguage, *boxInitWindow;
 	QCheckBox *boxAutoscale3DPlots, *boxTableComments, *boxThousandsSeparator;
-	QCheckBox *boxPromptRenameTables, *boxBackupProject, *boxLabelsEditing;
+	QCheckBox *boxPromptRenameTables, *boxBackupProject, *boxLabelsEditing, *boxEmptyCellGap;
 	QWidget *fileLocationsPage;
 	QLabel *lblTranslationsPath, *lblHelpPath, *lblUndoStackSize, *lblEndOfLine;
 	QLineEdit *translationsPathLine, *helpPathLine;
@@ -239,6 +240,7 @@ private:
 	QLabel *labelGraphBkgOpacity, *labelGraphCanvasOpacity;
 	ColorButton *boxBackgroundColor, *boxCanvasColor, *boxBorderColor;
 	QSpinBox *boxBackgroundTransparency, *boxCanvasTransparency, *boxBorderWidth, *boxTabLength;
+	QSlider *bkgOpacitySlider, *canvasOpacitySlider, *curveOpacitySlider;
 	QCheckBox *completionBox, *lineNumbersBox;
 	QLabel *labelTabLength, *labelNotesFont;
 	QFontComboBox *boxFontFamily;
@@ -261,8 +263,8 @@ private:
     QPushButton *browseTexCompilerBtn;
     QLabel *texCompilerLabel;
 
-    QComboBox *legendDisplayBox;
-	QLabel *legendDisplayLabel;
+	QComboBox *legendDisplayBox, *attachToBox;
+	QLabel *legendDisplayLabel, *attachToLabel;
 
 	DoubleSpinBox *boxMajorGridWidth, *boxMinorGridWidth;
 	QComboBox *boxMajorGridStyle, *boxMinorGridStyle;
@@ -330,6 +332,9 @@ private:
 	QLineEdit *jodconverterPathBox;
 	QPushButton *browseJODConverterBtn;
 	QLabel *jodconverterLabel;
+
+	QLabel *excelImportMethodLabel;
+	QComboBox *excelImportMethod;
 };
 
 #endif // CONFIGDIALOG_H
