@@ -2,7 +2,7 @@
     File                 : PlotWizard.cpp
     Project              : QtiPlot
     --------------------------------------------------------------------
-	Copyright            : (C) 2004 - 2010 by Ion Vasilief
+	Copyright            : (C) 2004 - 2011 by Ion Vasilief
     Email (use @ for *)  : ion_vasilief*yahoo.fr
     Description          : A wizard type dialog to create new plots
 
@@ -33,7 +33,7 @@
 #include <MultiLayer.h>
 #include <Graph.h>
 #include <Table.h>
-#include <QwtErrorPlotCurve.h>
+#include <ErrorBarsCurve.h>
 
 #include <QApplication>
 #include <QHBoxLayout>
@@ -143,36 +143,28 @@ QSize PlotWizard::sizeHint() const
 void PlotWizard::accept()
 {
 	QStringList curves, curves3D, ribbons;
-	for (int i=0; i < plotAssociations->count(); i++)
-	{
+	for (int i=0; i < plotAssociations->count(); i++){
 		QString text = plotAssociations->item(i)->text();
-        if (text.endsWith("(X)"))
-        {
-            QMessageBox::critical(this, tr("QtiPlot - Error"),
-            tr("Please define a Y column for the following curve") + ":\n\n" + text);
-            return;
-        }
+		if (text.endsWith("(X)")){
+			QMessageBox::critical(this, tr("QtiPlot - Error"),
+			tr("Please define a Y column for the following curve") + ":\n\n" + text);
+			return;
+		}
 
-		if ( text.contains("(Z)") )
-		{
+		if ( text.contains("(Z)") ){
 			if ( text.contains("(Y)") && !curves3D.contains(text) )
 				curves3D << text;
 			else if ( !text.contains("(Y)") && !ribbons.contains(text) )
 				ribbons << text;
-		}
-		else if ( text.contains("(xErr)") || text.contains("(yErr)"))
-		{
+		} else if ( text.contains("(xErr)") || text.contains("(yErr)")){
 			QStringList lst = text.split(",", QString::SkipEmptyParts);
 			lst.pop_back();
 			QString master_curve = lst.join(",");
-
 			if (!curves.contains(master_curve))
 				curves.prepend(master_curve);
-
 			if (!curves.contains(text))
 				curves << text; //add error bars at the end of the list.
-		}
-		else if (!curves.contains(text))
+		} else
 			curves.prepend(text);
 	}
 
@@ -442,10 +434,10 @@ void PlotWizard::plot2D(const QStringList& colList)
 			posY = s.find(",", posY);
 			int posErr, errType;
 			if (s.contains("(yErr)")){
-				errType = QwtErrorPlotCurve::Vertical;
+				errType = ErrorBarsCurve::Vertical;
 				posErr = s.find("(yErr)", posY);
 			} else {
-				errType = QwtErrorPlotCurve::Horizontal;
+				errType = ErrorBarsCurve::Horizontal;
 				posErr = s.find("(xErr)",posY);
 			}
 
@@ -460,6 +452,7 @@ void PlotWizard::plot2D(const QStringList& colList)
 		ag->updateCurveLayout(c, &cl);
 	}
 	ag->updatePlot();
+	ag->updateAxesTitles();
 	ag->newLegend();
 	g->arrangeLayers(false, true);
 	QApplication::restoreOverrideCursor();
