@@ -2,7 +2,7 @@
     File                 : main.cpp
     Project              : QtiPlot
     --------------------------------------------------------------------
-    Copyright            : (C) 2006 by Ion Vasilief
+	Copyright            : (C) 2004 - 2011 by Ion Vasilief
     Email (use @ for *)  : ion_vasilief*yahoo.fr
     Description          : QtiPlot main function
 
@@ -119,8 +119,28 @@ If you want to contribute code, please read the notes on \ref style "coding styl
   - For indentations, tabs are preferred because they allow everyone to choose the indentation depth for him/herself.
 */
 
+#include <QtPlugin>
+
 int main( int argc, char ** argv )
 {
+#ifdef QTIPLOT_STATIC_BUILD
+	Q_IMPORT_PLUGIN(qgif);
+	Q_IMPORT_PLUGIN(qjpeg);
+	Q_IMPORT_PLUGIN(qmng);
+	Q_IMPORT_PLUGIN(qtiff);
+#endif
+
+#ifdef QTIPLOT_PRO
+	Q_IMPORT_PLUGIN(QtiPlotdBasePlugin);
+	Q_IMPORT_PLUGIN(QtiPlotCsvPlugin);
+	Q_IMPORT_PLUGIN(QtiPlotTexPlugin);
+	Q_IMPORT_PLUGIN(QtiPlotOdsPlugin);
+	Q_IMPORT_PLUGIN(QtiPlotExcelPlugin);
+	Q_IMPORT_PLUGIN(QtiPlotEmfExportPlugin);
+	Q_IMPORT_PLUGIN(QtiPlotOriginPlugin);
+	Q_IMPORT_PLUGIN(QtiPlotDatabasePlugin);
+#endif
+
 	QtiPlotApplication app( argc, argv );
 	app.connect( &app, SIGNAL(lastWindowClosed()), &app, SLOT(quit()) );
 	return app.exec();
