@@ -60,12 +60,15 @@ class ExtensibleFileDialog : public QFileDialog
 		bool isExtendable(){return d_extension != NULL;};
 		bool isExtended(){return d_extension_toggle->isChecked();};
 		//! Toggle extension widget on/off
-		void setExtended(bool extended){if (extended) d_extension_toggle->toggle();};
+		void setExtended(bool extended);
 		//! Sets the text to be displayed in the toggle button
 		void setExtentionToggleButtonText(const QString& text){d_extension_toggle->setText(text);};
 		//! Enables/Disables editing of the file type filter
 		void setEditableFilter(bool on = true);
 		
+	private slots:
+		void updateToggleButtonText(bool);
+
 	protected:
 		//! Button for toggling display of extension on/off.
 		QPushButton *d_extension_toggle;
