@@ -97,14 +97,14 @@ void MatrixModel::setImage(const QImage& image)
 {
 	if (!canResize(image.height(), image.width()))
 		return;
-
-    d_rows = image.height();
-    d_cols = image.width();
+	
+	d_rows = image.height();
+	d_cols = image.width();
 	int cell = 0;
-    for (int i=0; i<d_rows; i++ ){
-		for (int j=0; j<d_cols; j++)
-            d_data[cell++] = qGray(image.pixel (j, i));
-    }
+	for (int i = 0; i < d_rows; i++){
+		for (int j = 0; j < d_cols; j++)
+			d_data[cell++] = qGray(image.pixel (j, i));
+	}
 }
 
 Qt::ItemFlags MatrixModel::flags(const QModelIndex & index ) const
@@ -463,25 +463,23 @@ bool MatrixModel::removeRows(int row, int count, const QModelIndex & parent)
 
 QImage MatrixModel::renderImage()
 {
-    QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
+	QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 
 	QImage image(QSize(d_cols, d_rows), QImage::Format_RGB32);
-	QwtLinearColorMap color_map = d_matrix->colorMap();
+	LinearColorMap color_map = d_matrix->colorMap();
 
-	double minValue = 0.0, maxValue = 0.0;
-	d_matrix->range(&minValue, &maxValue);
-    const QwtDoubleInterval intensityRange = QwtDoubleInterval (minValue, maxValue);
-    for ( int i = 0; i < d_rows; i++ ){
-    	QRgb *line = (QRgb *)image.scanLine(i);
+	const QwtDoubleInterval intensityRange = d_matrix->colorRange();
+	for ( int i = 0; i < d_rows; i++ ){
+		QRgb *line = (QRgb *)image.scanLine(i);
 		for ( int j = 0; j < d_cols; j++){
-		    double val = d_data[i*d_cols + j];
-		    if (gsl_isnan (val))
-                *line++ = color_map.rgb(intensityRange, 0.0);
+			double val = d_data[i*d_cols + j];
+			if (gsl_isnan (val))
+				*line++ = color_map.rgb(intensityRange, 0.0);
 			else if(fabs(val) < HUGE_VAL)
 				*line++ = color_map.rgb(intensityRange, val);
 		}
-     }
-     QApplication::restoreOverrideCursor();
+	 }
+	 QApplication::restoreOverrideCursor();
 	 return image;
 }
 
@@ -536,7 +534,7 @@ bool MatrixModel::importASCII(const QString &fname, const QString &sep, int igno
 		break;
 	}
 
-	for (int j = startCol; j<d_cols; j++){
+	for (int j = startCol; j < d_cols; j++){
 		int aux = j - startCol;
 		if (cols > aux){
 			if (updateDecimalSeparators)
@@ -547,28 +545,48 @@ bool MatrixModel::importASCII(const QString &fname, const QString &sep, int igno
 	}
 
 	qApp->processEvents(QEventLoop::ExcludeUserInput);
-	for (int i = startRow; i<d_rows; i++){
-		s = t.readLine();
-		if (simplifySpaces)
-			s = s.simplifyWhiteSpace();
-		else if (stripSpaces)
-			s = s.stripWhiteSpace();
-		line = s.split(sep);
-		int lc = line.size();
-		if (lc > cols)
-			setColumnCount(d_cols + lc - cols);
+	if (startCol){
+		for (int i = startRow; i < d_rows; i++){
+			s = t.readLine();
+			if (simplifySpaces)
+				s = s.simplifyWhiteSpace();
+			else if (stripSpaces)
+				s = s.stripWhiteSpace();
+			line = s.split(sep);
 
-		for (int j = startCol; j<d_cols; j++){
-			int aux = j - startCol;
-		    if (lc > aux){
+			int nc = line.size() + startCol;
+			if (nc > d_cols)
+				setColumnCount(nc);
+
+			for (int j = startCol; j < nc; j++){
 				if (updateDecimalSeparators)
-					setCell(i, j, locale.toDouble(line[aux]));
+					setCell(i, j, locale.toDouble(line[j - startCol]));
 				else
-					setText(i, j, line[aux]);
+					setText(i, j, line[j - startCol]);
+			}
+		}
+	} else {
+		for (int i = startRow; i < d_rows; i++){
+			s = t.readLine();
+			if (simplifySpaces)
+				s = s.simplifyWhiteSpace();
+			else if (stripSpaces)
+				s = s.stripWhiteSpace();
+			line = s.split(sep);
+			int lc = line.size();
+			if (lc > d_cols)
+				setColumnCount(lc);
+
+			for (int j = 0; j < lc; j++){
+				if (updateDecimalSeparators)
+					setCell(i, j, locale.toDouble(line[j]));
+				else
+					setText(i, j, line[j]);
 			}
 		}
 	}
-    f.remove();	//remove temp file
+
+	f.remove();	//remove temp file
 	if (d_matrix)
 		d_matrix->resetView();
 	QApplication::restoreOverrideCursor();
