@@ -29,6 +29,7 @@
 #include "MatrixValuesDialog.h"
 #include "MatrixCommand.h"
 #include <ApplicationWindow.h>
+#include "muParserScripting.h"
 
 #include <QLayout>
 #include <QSpinBox>
@@ -70,6 +71,7 @@ MatrixValuesDialog::MatrixValuesDialog( ScriptingEnv *env, QWidget* parent, Qt::
 	gl1->addWidget(endCol, 1, 3);
 
 	functions = new QComboBox(false);
+	functions->addItems(scriptEnv->mathFunctions());
 	btnAddFunction = new QPushButton(tr( "Add &Function" ));
 	btnAddCell = new QPushButton(tr( "Add Ce&ll" ));
 
@@ -119,14 +121,15 @@ MatrixValuesDialog::MatrixValuesDialog( ScriptingEnv *env, QWidget* parent, Qt::
 	boxMuParser = NULL;
 	if (scriptEnv->name() != QString("muParser")){
 		boxMuParser = new QCheckBox(tr("Use built-in muParser (much faster)"));
-		boxMuParser->setChecked(true);
+		boxMuParser->setChecked(((ApplicationWindow *)parent)->d_force_muParser);
+		connect(boxMuParser, SIGNAL(toggled(bool)), this, SLOT(updateFunctionsList(bool)));
+		updateFunctionsList(boxMuParser->isChecked());
 		vbox3->addWidget(boxMuParser);
 	}
 #endif
 	vbox3->addWidget(new QLabel(tr( "Cell(i,j)=" )));
 	vbox3->addLayout(hbox3);
 
-	functions->insertStringList(scriptEnv->mathFunctions(), -1);
 	insertExplain(0);
 
 	connect(btnAddCell, SIGNAL(clicked()), this, SLOT(addCell()));
@@ -201,7 +204,14 @@ void MatrixValuesDialog::setMatrix(Matrix* m)
 
 void MatrixValuesDialog::insertExplain(int index)
 {
+#ifdef SCRIPTING_PYTHON
+	if (boxMuParser && boxMuParser->isChecked())
+		explain->setText(muParserScripting::explainFunction(functions->text(index)));
+	else
+		explain->setText(scriptEnv->mathFunctionDoc(functions->text(index)));
+#else
 	explain->setText(scriptEnv->mathFunctionDoc(functions->text(index)));
+#endif
 }
 
 void MatrixValuesDialog::insertFunction()
@@ -221,3 +231,29 @@ void MatrixValuesDialog::setCompleter(QCompleter *completer)
 
     commands->setCompleter(completer);
 }
+
+void MatrixValuesDialog::closeEvent(QCloseEvent* e)
+{
+#ifdef SCRIPTING_PYTHON
+	if (boxMuParser){
+		ApplicationWindow *app = (ApplicationWindow *)this->parent();
+		if (app)
+			app->d_force_muParser = boxMuParser->isChecked();
+	}
+#endif
+	e->accept();
+}
+
+#ifdef SCRIPTING_PYTHON
+void MatrixValuesDialog::updateFunctionsList(bool muParser)
+{
+	functions->clear();
+	if (muParser)
+		functions->addItems(muParserScripting::functionsList());
+	else
+		functions->addItems(scriptingEnv()->mathFunctions());
+
+	if (functions->count() > 0)
+		insertExplain(0);
+}
+#endif
