@@ -39,10 +39,11 @@ class BoxCurve: public DataCurve
 public:
 	enum BoxStyle{NoBox, Rect, Diamond, WindBox, Notch};
 	enum Range{None, SD, SE, r25_75, r10_90, r5_95, r1_99, MinMax, UserDef};
+	enum LabelsDisplayPolicy{Percentage, Value, PercentageValue, ValuePercentage};
 
 	BoxCurve(Table *t, const QString& name, int startRow = 0, int endRow = -1);
 
-	void copy(const BoxCurve *b);
+	void copy(BoxCurve *b);
 
 	virtual QwtDoubleRect boundingRect() const;
 
@@ -75,8 +76,22 @@ public:
 	int whiskersRangeType(){return w_range;};
 	void setWhiskersRange(int type, double coeff = 0.0);
 
+	LabelsDisplayPolicy labelsDisplayPolicy(){return d_labels_display;};
+	void setLabelsDisplayPolicy(const LabelsDisplayPolicy& policy);
+
+	bool hasBoxLabels(){return d_box_labels;};
+	void showBoxLabels(bool on = true);
+
+	bool hasWhiskerLabels(){return d_whiskers_labels;};
+	void showWhiskerLabels(bool on = true);
+
     void loadData();
 
+	QString statistics();
+
+	double median(){return quantile(0.5);};
+	double quantile(double f);
+
 private:
 	void draw(QPainter *painter,const QwtScaleMap &xMap,
 		const QwtScaleMap &yMap, int from, int to) const;
@@ -85,9 +100,28 @@ private:
 	void drawSymbols(QPainter *painter, const QwtScaleMap &xMap,
 				const QwtScaleMap &yMap, double *dat, int size) const;
 
-	QwtSymbol::Style min_style, max_style, mean_style, p99_style, p1_style;
-	double b_coeff, w_coeff;
-	int b_style, b_width, b_range, w_range;
+	double* statisticValues();
+	QString labelText(int index, double val);
+	QString labelPercentage(int index);
+	void createLabel(double val);
+	virtual void loadLabels();
+	void updateLabels(bool updateText = true);
+	void updateLabelsPosition(){updateLabels(false);};
+
+	QwtSymbol::Style min_style;
+	QwtSymbol::Style max_style;
+	QwtSymbol::Style mean_style;
+	QwtSymbol::Style p99_style;
+	QwtSymbol::Style p1_style;
+	double b_coeff;
+	double w_coeff;
+	int b_range;
+	int w_range;
+	int b_style;
+	int b_width;
+	bool d_box_labels;
+	bool d_whiskers_labels;
+	LabelsDisplayPolicy d_labels_display;
 };
 
 
