@@ -136,7 +136,7 @@ class Graph: public QwtPlot
 			Spline, HorizontalSteps, Histogram, HorizontalBars, VectXYXY, ErrorBars,
 			Box, VectXYAM, VerticalSteps, ColorMap, GrayScale, Contour, Function, ImagePlot,
 			StackBar, StackColumn};
-		enum LegendDisplayMode{Auto, ColumnName, ColumnComment, TableName, TableLegend};
+		enum LegendDisplayMode{Auto, ColumnName, ColumnComment, TableName, TableLegend, DataSetName};
 		enum AxisTitlePolicy{Default, ColName, ColComment, NameAndComment};
 
 		//! Returns a pointer to the parent MultiLayer object.
@@ -384,6 +384,8 @@ class Graph: public QwtPlot
 				bool through = true, bool minus = true, bool plus = true);
 
 		void updateErrorBars(ErrorBarsCurve *er, bool xErr, double width, int cap, const QColor& c, bool plus, bool minus, bool through);
+		//! Used when restoring project files
+		void loadErrorBars(QList<ErrorBarsCurve *> errBars, QList<int> mcIndexes);
 
 		//! Returns a valid master curve for the error bars curve.
 		DataCurve* masterCurve(ErrorBarsCurve *er);
