@@ -59,7 +59,7 @@ d_angle(0),
 h_space(5),
 left_margin(10),
 top_margin(5),
-line_length(20),
+line_length(32),
 d_auto_update(false),
 d_tex_output(false)
 {
@@ -80,7 +80,6 @@ d_tex_output(false)
 	setMouseTracking(true);
 	show();
 	setFocus();
-	d_attach_policy = Page;
 }
 
 void LegendWidget::paintEvent(QPaintEvent *e)
@@ -89,7 +88,7 @@ void LegendWidget::paintEvent(QPaintEvent *e)
 
 	const int symbolLineLength = line_length + symbolsMaxWidth();
 	int width, height, textWidth, textHeight;
-	QwtArray<long> heights = itemsHeight(&p, symbolLineLength, width, height, textWidth, textHeight);
+	QwtArray<long> heights = itemsHeight(&p, symbolLineLength, d_frame_pen.width(), width, height, textWidth, textHeight);
     resize(width, height);
 
 	drawFrame(&p, rect());
@@ -115,20 +114,18 @@ void LegendWidget::print(QPainter *painter, const QwtScaleMap map[QwtPlot::axisC
 	left_margin = int(left_margin*xfactor);
 	top_margin = int(top_margin*yfactor);
 
+	const int dfy = qRound(d_frame_pen.width()*yfactor);
 	const int symbolLineLength = int((line_length + symbolsMaxWidth())*xfactor);
 	int width, height, textWidth, textHeight;
-	QwtArray<long> heights = itemsHeight(painter, symbolLineLength, width, height, textWidth, textHeight);
-
-	int dfx = qRound(d_frame_pen.width()*xfactor);
-	int dfy = qRound(d_frame_pen.width()*yfactor);
+	QwtArray<long> heights = itemsHeight(painter, symbolLineLength, dfy, width, height, textWidth, textHeight);
 
 #ifdef TEX_OUTPUT
 	if (plot()->isExportingTeX()){
-		drawFrame(painter, QRect(x, y, qRound(this->width()*xfactor), height).adjusted(-dfx, -dfy, dfx, dfy));
+		drawFrame(painter, QRect(x, y, qRound(this->width()*xfactor), height));
 		((QTeXPaintDevice *)painter->device())->setTextHorizontalAlignment(Qt::AlignLeft);
 	} else
 #endif
-		drawFrame(painter, QRect(x, y, width, height).adjusted(-dfx, -dfy, dfx, dfy));
+	drawFrame(painter, QRect(x, y, width, height));
 
 	drawText(painter, QRect(x, y, textWidth, textHeight), heights, symbolLineLength);
 
@@ -260,8 +257,7 @@ void LegendWidget::drawSymbol(PlotCurve *c, int point, QPainter *p, int x, int y
 	p->restore();
 }
 
-void LegendWidget::drawText(QPainter *p, const QRect& rect,
-		QwtArray<long> height, int symbolLineLength)
+void LegendWidget::drawText(QPainter *p, const QRect& rect, QwtArray<long> height, int symbolLineLength)
 {
 	p->save();
 	if (d_plot->antialiasing())
@@ -290,7 +286,7 @@ void LegendWidget::drawText(QPainter *p, const QRect& rect,
 	QString text = d_text->text();
 	QStringList titles = text.split("\n", QString::KeepEmptyParts);
 
-	for (int i=0; i<(int)titles.count(); i++){
+	for (int i = 0; i < titles.count(); i++){
 		int w = left_margin + d_frame_pen.width();
 		bool  curveSymbol = false;
 		QString s = titles[i];
@@ -303,7 +299,7 @@ void LegendWidget::drawText(QPainter *p, const QRect& rect,
 				QwtText aux(parse(s.left(pos))); //not a pie chart
 				aux.setFont(d_text->font());
 				aux.setColor(d_text->color());
-				aux.setRenderFlags (Qt::AlignLeft | Qt::AlignVCenter);
+				aux.setRenderFlags (Qt::AlignLeft | Qt::AlignVCenter | Qt::TextExpandTabs);
 
 				QSize size = textSize(p, aux);
 				QRect tr = QRect(QPoint(w, height[i] - size.height()/2), size);
@@ -332,7 +328,7 @@ void LegendWidget::drawText(QPainter *p, const QRect& rect,
                     QwtText aux(parse(s.left(pos)));
                     aux.setFont(d_text->font());
                     aux.setColor(d_text->color());
-					aux.setRenderFlags (Qt::AlignLeft | Qt::AlignVCenter);
+					aux.setRenderFlags (Qt::AlignLeft | Qt::AlignVCenter | Qt::TextExpandTabs);
 
 					QSize size = textSize(p, aux);
                     QRect tr = QRect(QPoint(w, height[i] - size.height()/2), size);
@@ -355,7 +351,7 @@ void LegendWidget::drawText(QPainter *p, const QRect& rect,
 						QwtText aux(parse(s.left(pos)));
 						aux.setFont(d_text->font());
 						aux.setColor(d_text->color());
-						aux.setRenderFlags (Qt::AlignLeft | Qt::AlignVCenter);
+						aux.setRenderFlags (Qt::AlignLeft | Qt::AlignVCenter | Qt::TextExpandTabs);
 
 						QSize size = textSize(p, aux);
 						QRect tr = QRect(QPoint(w, height[i] - size.height()/2), size);
@@ -383,7 +379,7 @@ void LegendWidget::drawText(QPainter *p, const QRect& rect,
 			QwtText aux(parse(s));
 			aux.setFont(d_text->font());
 			aux.setColor(d_text->color());
-			aux.setRenderFlags (Qt::AlignLeft | Qt::AlignVCenter);
+			aux.setRenderFlags (Qt::AlignLeft | Qt::AlignVCenter | Qt::TextExpandTabs);
 
 			QSize size = textSize(p, aux);
 			QRect tr = QRect(QPoint(w, height[i] - size.height()/2), size);
@@ -393,7 +389,7 @@ void LegendWidget::drawText(QPainter *p, const QRect& rect,
 	p->restore();
 }
 
-QwtArray<long> LegendWidget::itemsHeight(QPainter *p, int symbolLineLength, int &width, int &height,
+QwtArray<long> LegendWidget::itemsHeight(QPainter *p, int symbolLineLength, int frameWidth, int &width, int &height,
 							 int &textWidth, int &textHeight)
 {
 	QString text = d_text->text();
@@ -404,7 +400,7 @@ QwtArray<long> LegendWidget::itemsHeight(QPainter *p, int symbolLineLength, int
 	width = 0;
 	height = 0;
 	int maxL = 0;
-	int h = top_margin + d_frame_pen.width();
+	int h = top_margin + frameWidth;
 	for (int i=0; i<n; i++){
 		QString s = titles[i];
 		int textL = 0;
@@ -417,6 +413,7 @@ QwtArray<long> LegendWidget::itemsHeight(QPainter *p, int symbolLineLength, int
 			if (pos >= 0 && (pos2==-1 || pos2>pos3)){
 				QwtText aux(parse(s.left(pos))); //not a pie chart
 				aux.setFont(d_text->font());
+				aux.setRenderFlags (Qt::AlignLeft | Qt::AlignVCenter | Qt::TextExpandTabs);
 				QSize size = textSize(p, aux);
 				textL += size.width();
 
@@ -440,6 +437,7 @@ QwtArray<long> LegendWidget::itemsHeight(QPainter *p, int symbolLineLength, int
                 if (pos >= 0){
                     QwtText aux(parse(s.left(pos)));
                     aux.setFont(d_text->font());
+					aux.setRenderFlags (Qt::AlignLeft | Qt::AlignVCenter | Qt::TextExpandTabs);
                     QSize size = textSize(p, aux);
                     textL += size.width();
                     textL += symbolLineLength;
@@ -451,6 +449,7 @@ QwtArray<long> LegendWidget::itemsHeight(QPainter *p, int symbolLineLength, int
 					if (pos >= 0){
 						QwtText aux(parse(s.left(pos)));
 						aux.setFont(d_text->font());
+						aux.setRenderFlags (Qt::AlignLeft | Qt::AlignVCenter | Qt::TextExpandTabs);
 						QSize size = textSize(p, aux);
 						textL += size.width();
 						textL += symbolLineLength;
@@ -464,6 +463,7 @@ QwtArray<long> LegendWidget::itemsHeight(QPainter *p, int symbolLineLength, int
 
 		QwtText aux(parse(s));
 		aux.setFont(d_text->font());
+		aux.setRenderFlags (Qt::AlignLeft | Qt::AlignVCenter | Qt::TextExpandTabs);
 		QSize size = textSize(p, aux);
 		textL += size.width();
 		if (curveSymbol)
@@ -482,7 +482,7 @@ QwtArray<long> LegendWidget::itemsHeight(QPainter *p, int symbolLineLength, int
 	height += 2*top_margin;
 	width = 2*left_margin + maxL;
 
-	int fw = 2*d_frame_pen.width();
+	int fw = 2*frameWidth;
     height += fw;
     width += fw;
 
@@ -596,18 +596,18 @@ QString LegendWidget::parse(const QString& str)
 		if (!lst.isEmpty()){
 			int lcmd = -1;
 			if (lst.count() >= 2){
-				if (lst[1].contains("@d",Qt::CaseInsensitive)) //look for d cmd (use curve name), default
-					lcmd=0;
-				else if (lst[1].contains("@c",Qt::CaseInsensitive)) //look for c cmd (use column name)
-					lcmd=1;
-				else if (lst[1].contains("@w",Qt::CaseInsensitive)) //look for w cmd (use table name)
-					lcmd=2;
-				else if (lst[1].contains("@wl",Qt::CaseInsensitive)) //look for wl cmd (use table label)
-					lcmd=3;
-				else if (lst[1].contains("@l",Qt::CaseInsensitive)) //look for l cmd (use column comment)
-					lcmd=4;
-				else if (lst[1].contains("@u",Qt::CaseInsensitive)) //look for c cmd (use column comment)
-					lcmd=5;
+				if (lst[1].contains("@d", Qt::CaseInsensitive)) //look for d cmd (use curve name), default
+					lcmd = 0;
+				else if (lst[1].contains("@c", Qt::CaseInsensitive)) //look for c cmd (use column name)
+					lcmd = 1;
+				else if (lst[1].contains("@wl", Qt::CaseInsensitive)) //look for w cmd (use table name)
+					lcmd = 3;
+				else if (lst[1].contains("@w", Qt::CaseInsensitive)) //look for wl cmd (use table label)
+					lcmd = 2;
+				else if (lst[1].contains("@l", Qt::CaseInsensitive)) //look for l cmd (use column comment)
+					lcmd = 4;
+				else if (lst[1].contains("@u", Qt::CaseInsensitive)) //look for c cmd (use column comment)
+					lcmd = 5;
 			}
 
 			int point = 0;
@@ -628,7 +628,10 @@ QString LegendWidget::parse(const QString& str)
 					switch(lcmd){
 						case -1: //use column name
 						{
-							s = s.replace(pos, pos2-pos+1, colLabel);
+							if (ycol >= 0 && !t->comment(ycol).isEmpty())
+								s = s.replace(pos, pos2-pos+1, t->comment(ycol).replace("\n", " "));
+							else
+								s = s.replace(pos, pos2-pos+1, colLabel);
 							break;
 						}
 						case 0: //use curve title
@@ -648,7 +651,10 @@ QString LegendWidget::parse(const QString& str)
 							break;
 						}
 						case 3: // table label
-							s = s.replace(pos, pos2-pos+1, t->windowLabel());
+							if (!t->windowLabel().isEmpty())
+								s = s.replace(pos, pos2-pos+1, t->windowLabel());
+							else
+								s = s.replace(pos, pos2-pos+1, colLabel);
 							break;
 						case 5: //not implemented yet, use case 4 (L) instead
 						case 4: //use col comment for 2 arguments, use cell contents for 3 arguments
@@ -656,7 +662,7 @@ QString LegendWidget::parse(const QString& str)
 							switch (lst.count()){
 								case 2: //2 arguments
 								{
-									s = s.replace(pos, pos2-pos+1, t->comment(ycol));
+									s = s.replace(pos, pos2-pos+1, t->comment(ycol).replace("\n", " "));
 									break;
 								}
 								case 3:  //3 arguments, display cell contents
@@ -804,6 +810,8 @@ void LegendWidget::restore(Graph *g, const QStringList& lst)
 			l->setAttachPolicy((FrameWidget::AttachPolicy)s.remove("<attachTo>").remove("</attachTo>").toInt());
 		else if (s.contains("<onTop>"))
 			l->setOnTop(s.remove("<onTop>").remove("</onTop>").toInt());
+		else if (s.contains("<visible>"))
+			l->setVisible(s.remove("<visible>").remove("</visible>").toInt());
 		else if (s.contains("<Text>")){
 			QStringList txt;
 			while ( s != "</Text>" ){
