@@ -99,12 +99,6 @@ public:
 	virtual QString sizeToString();
 
 	void setWaterfallLayout(bool on = true);
-	void createWaterfallBox();
-	bool isWaterfallPlot(){return d_is_waterfall_plot;};
-	int waterfallXOffset(){return d_waterfall_offset_x;};
-	int waterfallYOffset(){return d_waterfall_offset_y;};
-	void setWaterfallOffset(int x, int y, bool update = false);
-	bool sideLinesEnabled(){return d_side_lines;};
 
 	void setEqualSizedLayers();
 
@@ -128,6 +122,8 @@ public:
 	bool hasSelectedLayers();
 	bool isLayerSelected(Graph*);
 
+	void adjustLayersToCanvasSize();
+
 public slots:
 	Graph* addLayer(int x = 0, int y = 0, int width = 0, int height = 0, bool = false);
 
@@ -150,7 +146,6 @@ public slots:
 	QSize arrangeLayers(bool userSize);
 	bool arrangeLayers(bool fit, bool userSize);
 	bool swapLayers(int src, int dest);
-    void adjustSize();
 	void updateLayersLayout(Graph *);
 
 	int getRows(){return d_rows;};
@@ -184,12 +179,14 @@ public slots:
 	void exportImage(QTextDocument *document, int quality = 100, bool transparent = false,
 		int dpi = 0, const QSizeF& customSize = QSizeF (), int unit = FrameWidget::Pixel, double fontsFactor = 1.0);
 #endif
-	void exportImage(const QString& fileName, int quality = 100, bool transparent = false,
-		int dpi = 0, const QSizeF& customSize = QSizeF (), int unit = FrameWidget::Pixel, double fontsFactor = 1.0);
+	void exportImage(const QString& fileName, int quality = 100, bool transparent = false, int dpi = 0,
+		const QSizeF& customSize = QSizeF (), int unit = FrameWidget::Pixel, double fontsFactor = 1.0, int compression = 0);
 	void exportSVG(const QString& fname, const QSizeF& customSize = QSizeF(), int unit = FrameWidget::Pixel, double fontsFactor = 1.0);
     void exportPDF(const QString& fname);
 	void exportVector(const QString& fileName, int res = 0, bool color = true,
 		const QSizeF& customSize = QSizeF (), int unit = FrameWidget::Pixel, double fontsFactor = 1.0);
+	void exportVector(QPrinter *printer, int res = 0, bool color = true,
+		const QSizeF& customSize = QSizeF (), int unit = FrameWidget::Pixel, double fontsFactor = 1.0);
 
 	void draw(QPaintDevice *, const QSizeF& customSize, int unit, int res, double fontsFactor = 1.0);
 
@@ -216,13 +213,10 @@ public slots:
     void showWaterfallOffsetDialog();
     void reverseWaterfallOrder();
     void showWaterfallFillDialog();
-    void setWaterfallFillColor(const QColor&);
-    void updateWaterfallFill(bool on);
-    void setWaterfallSideLines(bool on = true);
-	void changeWaterfallXOffset(int);
-    void changeWaterfallYOffset(int);
-    void updateWaterfallLayout();
-    void updateWaterfallScales(Graph *g, int axis);
+	void updateWaterfalls();
+	bool isWaterfallPlot(){return d_is_waterfall_plot;}
+	QColor waterfallFillColor(){return d_waterfall_fill_color;}
+	void setWaterfallFillColor(const QColor& c);
     //@}
 
 	void updateLayerAxes(Graph *g, int axis);
@@ -244,6 +238,7 @@ private:
 	//! \name Event Handlers
 	//@{
 	void mouseReleaseEvent(QMouseEvent *);
+	void showEvent(QShowEvent *);
 	void dropEvent(QDropEvent*);
 	void dragEnterEvent(QDragEnterEvent*);
 	void wheelEvent(QWheelEvent *);
@@ -256,6 +251,7 @@ private:
 	//@}
 
 	LayerButton* addLayerButton();
+	void createWaterfallBox();
 
 	Graph* active_graph;
 	//! Used for resizing of layers.
@@ -273,10 +269,7 @@ private:
 
 	QPointer<SelectionMoveResizer> d_layers_selector;
 
-	int d_waterfall_offset_x, d_waterfall_offset_y;
 	bool d_is_waterfall_plot;
-	//! Flag telling if we need to draw side lines for curves in a waterfall plot
-	bool d_side_lines;
 	QColor d_waterfall_fill_color;
 
 	QPushButton *d_add_layer_btn, *d_remove_layer_btn;
