@@ -93,6 +93,11 @@ signals:
 	 */
 	void axisDblClicked(int);
 
+	/*! Emitted when the user double-clicks on the ticks of an axis.
+	 * The argument specifies the axis' QwtScaleDraw::Alignment.
+	 */
+	void axisTicksDblClicked(int);
+
 	/*! Emitted when the user double-clicks on an the axis title.
 	 */
 	void axisTitleDblClicked();
@@ -102,6 +107,7 @@ private:
 	void mouseDblClicked(const QwtScaleWidget *, const QPoint &);
 	void mouseClicked(const QwtScaleWidget *scale, const QPoint &pos) ;
 	void mouseRightClicked(const QwtScaleWidget *scale, const QPoint &pos);
+	bool labelClicked(const QwtScaleWidget *scale, const QPoint &pos);
 
 	bool d_title_selected;
 	bool d_labels_selected;
