@@ -2,7 +2,7 @@
     File                 : VectorCurve.h
     Project              : QtiPlot
     --------------------------------------------------------------------
-    Copyright            : (C) 2006 by Ion Vasilief
+	Copyright            : (C) 2006 - 2010 by Ion Vasilief
     Email (use @ for *)  : ion_vasilief*yahoo.fr
     Description          : Vector curve class
 
@@ -50,19 +50,9 @@ public:
 
 	QwtDoubleRect boundingRect() const;
 
-	void draw(QPainter *painter,const QwtScaleMap &xMap,
-		const QwtScaleMap &yMap, int from, int to) const;
-
-	void drawVector(QPainter *painter, const QwtScaleMap &xMap,
-		const QwtScaleMap &yMap, int from, int to) const;
-
-	void drawArrowHead(QPainter *p, int xs, int ys, int xe, int ye) const;
-	double theta(int x0, int y0, int x1, int y1) const;
-
 	QString vectorEndXAColName(){return d_end_x_a;};
 	QString vectorEndYMColName(){return d_end_y_m;};
 	void setVectorEnd(const QString& xColName, const QString& yColName);
-	void setVectorEnd(const QwtArray<double>&x, const QwtArray<double>&y);
 
 	double width();
 	void setWidth(double w);
@@ -88,20 +78,31 @@ public:
 	bool updateData(Table *t, const QString& colName);
 	void loadData();
 
-    QString plotAssociation();
+	QStringList plotAssociation();
 	void updateColumnNames(const QString& oldName, const QString& newName, bool updateTableName);
 
 	QPen vectorPen(){return d_pen;};
 	void setVectorPen(const QPen& pen){d_pen = pen;};
 
+private:
+	void setVectorEnd(const QwtArray<double>&x, const QwtArray<double>&y);
+
+	void draw(QPainter *painter,const QwtScaleMap &xMap,
+		const QwtScaleMap &yMap, int from, int to) const;
+
+	void drawVector(QPainter *painter, const QwtScaleMap &xMap,
+		const QwtScaleMap &yMap, int from, int to) const;
+
+	void drawArrowHead(QPainter *p, int xs, int ys, int xe, int ye) const;
+		double theta(int x0, int y0, int x1, int y1) const;
+
 protected:
-	QwtArrayData *vectorEnd;
 	QPen d_pen;
 	bool filledArrow;
 	int d_style, d_headLength, d_headAngle, d_position;
-
 	QString d_end_x_a;
 	QString d_end_y_m;
+	QwtArrayData *vectorEnd;
 };
 
 #endif
