@@ -2,7 +2,8 @@
     File                 : AxesDialog.h
     Project              : QtiPlot
     --------------------------------------------------------------------
-    Copyright            : (C) 2006 by Ion Vasilief, Tilman Hoener zu Siederdissen
+	Copyright            : (C) 2004 - 2011 by Ion Vasilief
+						   (C) 2006 Tilman Hoener zu Siederdissen
 	Email (use @ for *)  : ion_vasilief*yahoo.fr
 	Description          : Axes preferences dialog
 
@@ -124,7 +125,6 @@ private slots:
     void applyCanvasFormat();
     void setFrameDefaultValues();
 	void applyAxisFormat();
-	void setDisplayDateTimeFormat( const QString &);
 	void updateCurrentAxis();
 
 protected:
@@ -201,13 +201,11 @@ protected:
 	//! Last selected tab
   	QWidget* lastPage;
     QDateTimeEdit *boxStartDateTime, *boxEndDateTime;
-    QTimeEdit *boxStartTime, *boxEndTime;
     QComboBox *canvasFrameApplyToBox;
     QPushButton *frameDefaultBtn;
 	QSpinBox *boxLabelsDistance;
 	QGroupBox *axisFormatBox;
 	QComboBox *axisFormatApplyToBox;
-	QDateTimeEdit *originDateTimeBox;
 	QCheckBox *invertTitleBox;
 	QCheckBox* boxAxisBackbone;
 	QSpinBox *boxTickLabelDistance;
