@@ -27,10 +27,11 @@
  *                                                                         *
  ***************************************************************************/
 #include "CurveRangeDialog.h"
-#include "../PlotCurve.h"
-#include "../Graph.h"
-#include "../../table/Table.h"
+#include "PlotCurve.h"
+#include "Graph.h"
+#include "Table.h"
 
+#include <QCheckBox>
 #include <QGroupBox>
 #include <QMessageBox>
 #include <QLayout>
@@ -42,10 +43,11 @@ CurveRangeDialog::CurveRangeDialog(QWidget* parent, Qt::WFlags fl )
     : QDialog( parent, fl )
 {
 	setWindowTitle(tr("QtiPlot - Plot range"));
-    setName( "CurveRangeDialog" );
+	setName( "CurveRangeDialog" );
+	setAttribute(Qt::WA_DeleteOnClose);
 
-    QGroupBox *gb1 = new QGroupBox();
-    QGridLayout *gl1 = new QGridLayout(gb1);
+	QGroupBox *gb1 = new QGroupBox();
+	QGridLayout *gl1 = new QGridLayout(gb1);
 	gl1->addWidget(new QLabel(tr("Data set: ")), 0, 0);
 
 	boxName = new QLabel();
@@ -59,34 +61,48 @@ CurveRangeDialog::CurveRangeDialog(QWidget* parent, Qt::WFlags fl )
 	gl1->addWidget(new QLabel(tr("To row number")), 2, 0);
 	boxEnd = new QSpinBox();
 	boxEnd->setMinValue(1);
-    gl1->addWidget(boxEnd, 2, 1);
-    gl1->setRowStretch(3, 1);
+	gl1->addWidget(boxEnd, 2, 1);
+
+	boxApplyToAll = new QCheckBox(tr("Apply to &all layer curves"));
+	gl1->addWidget(boxApplyToAll, 3, 0);
+	gl1->setRowStretch(4, 1);
 
 	buttonOK = new QPushButton(tr( "&OK" ));
-    buttonOK->setDefault( true );
-    buttonCancel = new QPushButton(tr( "&Close" ));
+	buttonOK->setDefault( true );
+	buttonCancel = new QPushButton(tr( "&Close" ));
 
-    QHBoxLayout *hl = new QHBoxLayout();
+	QHBoxLayout *hl = new QHBoxLayout();
 	hl->addStretch();
- 	hl->addWidget(buttonOK);
+	hl->addWidget(buttonOK);
 	hl->addWidget(buttonCancel);
 
-    QVBoxLayout *vb = new QVBoxLayout(this);
-    vb->addWidget(gb1);
-    vb->addLayout(hl);
+	QVBoxLayout *vb = new QVBoxLayout(this);
+	vb->addWidget(gb1);
+	vb->addLayout(hl);
 
 	connect( buttonOK, SIGNAL( clicked() ), this, SLOT( accept() ) );
-    connect( buttonCancel, SIGNAL( clicked() ), this, SLOT( reject() ) );
+	connect( buttonCancel, SIGNAL( clicked() ), this, SLOT( reject() ) );
 }
 
 void CurveRangeDialog::accept()
 {
-	if (!d_curve)
+	if (!d_graph)
 		return;
 
 	int start = boxStart->value() - 1;
 	int end = boxEnd->value() - 1;
-	d_curve->setRowRange(QMIN(start, end), QMAX(start, end));
+
+	if (boxApplyToAll->isChecked()){
+		for (int i = 0; i < d_graph->curveCount(); i++){
+			DataCurve *c = d_graph->dataCurve(i);
+			if (c)
+				c->setRowRange(QMIN(start, end), QMAX(start, end));
+		}
+	} else if (!d_curves.isEmpty()){
+		foreach(DataCurve *c, d_curves)
+			c->setRowRange(QMIN(start, end), QMAX(start, end));
+	}
+
 	d_graph->updatePlot();
 	d_graph->notifyChanges();
 	close();
@@ -98,13 +114,14 @@ void CurveRangeDialog::setCurveToModify(Graph *g, int curve)
 		return;
 
 	d_graph = g;
-	d_curve = (DataCurve *)d_graph->curve(curve);
+	DataCurve *d_curve = (DataCurve *)d_graph->curve(curve);
 	if (!d_curve)
 		return;
 
-    Table *t = d_curve->table();
-	if (t)
-	{
+	d_curves << d_curve;
+
+	Table *t = d_curve->table();
+	if (t){
 		boxStart->setMaxValue(t->numRows());
 		boxEnd->setMaxValue(t->numRows());
 	}
@@ -113,3 +130,34 @@ void CurveRangeDialog::setCurveToModify(Graph *g, int curve)
 	boxStart->setValue(d_curve->startRow() + 1);
 	boxEnd->setValue(d_curve->endRow() + 1);
 }
+
+void CurveRangeDialog::setCurvesToModify(Graph *g, const QList<int>& indexes)
+{
+	if (!g || indexes.isEmpty())
+		return;
+
+	d_graph = g;
+
+	QStringList curveNames;
+	foreach(int i, indexes){
+		DataCurve *c = (DataCurve *)d_graph->curve(i);
+		if (c){
+			d_curves << c;
+			curveNames << c->title().text();
+		}
+	}
+
+	if (d_curves.isEmpty())
+		return;
+
+	DataCurve *d_curve = d_curves[0];
+	Table *t = d_curve->table();
+	if (t){
+		boxStart->setMaxValue(t->numRows());
+		boxEnd->setMaxValue(t->numRows());
+	}
+
+	boxName->setText(curveNames.join("\n"));
+	boxStart->setValue(d_curve->startRow() + 1);
+	boxEnd->setValue(d_curve->endRow() + 1);
+}
