@@ -2,7 +2,7 @@
     File                 : LayerDialog.h
     Project              : QtiPlot
     --------------------------------------------------------------------
-    Copyright            : (C) 2004-2007 by Ion Vasilief
+	Copyright            : (C) 2004-2010 by Ion Vasilief
     Email (use @ for *)  : ion_vasilief*yahoo.fr
     Description          : Arrange layers dialog
 
@@ -33,6 +33,7 @@
 
 #include <QDialog>
 
+class DoubleSpinBox;
 class QGroupBox;
 class QPushButton;
 class QSpinBox;
@@ -45,16 +46,30 @@ class LayerDialog : public QDialog
     Q_OBJECT
 
 public:
-    LayerDialog( QWidget* parent = 0, Qt::WFlags fl = 0 );
+	LayerDialog(QWidget* parent, bool okMode = false, Qt::WFlags fl = 0);
 	void setMultiLayer(MultiLayer *g);
+	void setLayers(int layers);
+	void setLayerCanvasSize(int w, int h, int unit);
+	void setMargins(int, int, int, int);
+	void setRows(int);
+	void setColumns(int);
+	void setSharedAxes(bool = true);
 
 protected slots:
 	void accept();
 	void update();
 	void enableLayoutOptions(bool ok);
 	void swapLayers();
+	void updateSizes(int unit);
+	void adjustCanvasHeight(double width);
+	void adjustCanvasWidth(double height);
+	void showCommonAxesBox();
 
 private:
+	void closeEvent(QCloseEvent*);
+	int convertToPixels(double w, FrameWidget::Unit unit, int dimension);
+	double convertFromPixels(int w, FrameWidget::Unit unit, int dimension);
+
 	MultiLayer *multi_layer;
 
 	QPushButton* buttonOk;
@@ -64,10 +79,19 @@ private:
     QGroupBox *GroupCanvasSize, *GroupGrid;
     QSpinBox *boxX, *boxY, *boxColsGap, *boxRowsGap;
 	QSpinBox *boxRightSpace, *boxLeftSpace, *boxTopSpace, *boxBottomSpace;
-	QSpinBox *boxCanvasWidth, *boxCanvasHeight, *layersBox;
+	DoubleSpinBox *boxCanvasWidth, *boxCanvasHeight;
+	QSpinBox *layersBox;
 	QSpinBox *boxLayerDest, *boxLayerSrc;
 	QCheckBox *fitBox;
 	QComboBox *alignHorBox, *alignVertBox;
+	QComboBox *unitBox;
+	QCheckBox *keepRatioBox;
+	QComboBox *alignPolicyBox;
+	QCheckBox *commonAxesBox;
+	QCheckBox *fixedSizeBox;
+	QCheckBox *linkXAxesBox;
+
+	double aspect_ratio;
 };
 
 #endif
