@@ -32,7 +32,7 @@
 #include <ApplicationWindow.h>
 #include <MyParser.h>
 #include <MatrixModel.h>
-#include <ColorMapEditor.h>
+#include <LinearColorMap.h>
 
 #include <QApplication>
 #include <QMessageBox>
@@ -50,7 +50,6 @@
 
 #include <qwt3d_io_gl2ps.h>
 #include <qwt3d_coordsys.h>
-#include <qwt_color_map.h>
 
 #include <gsl/gsl_vector.h>
 #include <gsl/gsl_math.h>
@@ -1131,12 +1130,16 @@ void Graph3D::resetAxesLabels()
 {
 	QString s = labels[0];
 	if (s == "%(?X)"){
-		QStringList lst = plotAssociation.split(",");
-		if (!lst.isEmpty()){
-			s = lst[0].remove("(X)");
-			int pos = s.lastIndexOf("_");
-			if (pos > 0)
-				s = s.right(s.length() - pos - 1);
+		if (d_matrix)
+			s = tr("X axis");
+		else {
+			QStringList lst = plotAssociation.split(",");
+			if (!lst.isEmpty()){
+				s = lst[0].remove("(X)");
+				int pos = s.lastIndexOf("_");
+				if (pos > 0)
+					s = s.right(s.length() - pos - 1);
+			}
 		}
 	}
 
@@ -1147,12 +1150,16 @@ void Graph3D::resetAxesLabels()
 
 	s = labels[1];
 	if (s == "%(?Y)"){
-		QStringList lst = plotAssociation.split(",");
-		if (!lst.isEmpty()){
-			s = lst[1].remove("(Y)");
-			int pos = s.lastIndexOf("_");
-			if (pos > 0)
-				s = s.right(s.length() - pos - 1);
+		if (d_matrix)
+			s = tr("Y axis");
+		else {
+			QStringList lst = plotAssociation.split(",");
+			if (lst.size() > 1){
+				s = lst[1].remove("(Y)");
+				int pos = s.lastIndexOf("_");
+				if (pos > 0)
+					s = s.right(s.length() - pos - 1);
+			}
 		}
 	}
 
@@ -1163,12 +1170,16 @@ void Graph3D::resetAxesLabels()
 
 	s = labels[2];
 	if (s == "%(?Z)"){
-		QStringList lst = plotAssociation.split(",");
-		if (!lst.isEmpty()){
-			s = lst[2].remove("(Z)");
-			int pos = s.lastIndexOf("_");
-			if (pos > 0)
-				s = s.right(s.length() - pos - 1);
+		if (d_matrix)
+			s = tr("Z axis");
+		else {
+			QStringList lst = plotAssociation.split(",");
+			if (lst.size() > 2){
+				s = lst[2].remove("(Z)");
+				int pos = s.lastIndexOf("_");
+				if (pos > 0)
+					s = s.right(s.length() - pos - 1);
+			}
 		}
 	}
 
@@ -1543,9 +1554,15 @@ void Graph3D::updateScalesFromMatrix(double xl, double xr, double yl, double yr,
 	double **data = 0;
 	if (xmin <= xStart && xmax >= xEnd && ymin <= yStart && ymax >= yEnd){
 		data = Matrix::allocateMatrixData(cols, rows);
-		for (int i = 0; i < cols; i++ ){
-			for (int j = 0; j < rows; j++)
-				data[i][j] = d_matrix->cell(j, i);
+		for (int i = 0; i < cols; i++){
+			for (int j = 0; j < rows; j++){
+				double val = d_matrix->cell(j, i);
+				if (val < zmin)
+					val = zmin;
+				else if (val > zmax)
+					val = zmax;
+				data[i][j] = val;
+			}
 		}
 		d_active_curve->loadFromData(data, cols, rows, d_matrix->xStart(), d_matrix->xEnd(), d_matrix->yStart(), d_matrix->yEnd());
 	} else {
@@ -1575,7 +1592,12 @@ void Graph3D::updateScalesFromMatrix(double xl, double xr, double yl, double yr,
 				double dki, dkf;
 				dkf = modf(fabs((y - yStart)/dy), &dki);
 				int k = qRound(dki); if (dkf > 0.5) k++;
-				data[i][j] = d_matrix->cell(k, l);
+				double val = d_matrix->cell(k, l);
+				if (val < zmin)
+					val = zmin;
+				else if (val > zmax)
+					val = zmax;
+				data[i][j] = val;
 			}
 		}
 		d_active_curve->loadFromData(data, cols, rows, x_begin, x_end, y_begin, y_end);
@@ -2136,32 +2158,14 @@ void Graph3D::copyImage()
     sp->updateData();
 }
 
-void Graph3D::exportImage(const QString& fileName, int quality, bool transparent,
-						int dpi, const QSizeF& customSize, int unit, double fontsFactor)
+QPixmap Graph3D::pixmap(int dpi, const QSizeF& customSize, int unit, double fontsFactor)
 {
-    if (!dpi)
+	if (!dpi)
 		dpi = logicalDpiX();
 
 	QSize size = this->size();
-	if (customSize.isValid()){
-		switch(unit){
-			case FrameWidget::Pixel:
-				size = customSize.toSize();
-			break;
-			case FrameWidget::Inch:
-				size = QSize((qRound)(customSize.width()*dpi), (qRound)(customSize.height()*dpi));
-			break;
-			case FrameWidget::Millimeter:
-				size = QSize((qRound)(customSize.width()*dpi/25.4), (qRound)(customSize.height()*dpi/25.4));
-			break;
-			case FrameWidget::Centimeter:
-				size = QSize((qRound)(customSize.width()*dpi/2.54), (qRound)(customSize.height()*dpi/2.54));
-			break;
-			case FrameWidget::Point:
-				size = QSize((qRound)(customSize.width()*dpi/72.0), (qRound)(customSize.height()*dpi/72.0));
-			break;
-		}
-	}
+	if (customSize.isValid())
+		size = Graph::customPrintSize(customSize, unit, dpi);
 
 	if (fontsFactor == 0.0)
 		fontsFactor = (double)size.height()/(double)this->height();
@@ -2173,8 +2177,14 @@ void Graph3D::exportImage(const QString& fileName, int quality, bool transparent
 	scaleFonts(1.0/fontsFactor);
 
 	sp->updateData();
-	QImage image = pic.toImage();
+	return pic;
+}
 
+void Graph3D::exportImage(const QString& fileName, int quality, bool transparent,
+			int dpi, const QSizeF& customSize, int unit, double fontsFactor, int compression)
+{
+	QPixmap pic = pixmap(dpi, customSize, unit, fontsFactor);
+	QImage image = pic.toImage();
 	if (transparent){
 		QBitmap mask = pic.createMaskFromColor (QColor(Qt::white).rgb ());
 		pic.setMask(mask);
@@ -2197,7 +2207,15 @@ void Graph3D::exportImage(const QString& fileName, int quality, bool transparent
 		writer.write(document);
 	} else
 #endif
-		image.save(fileName, 0, quality);
+	{
+		QImageWriter writer(fileName);
+		if (compression > 0 && writer.supportsOption(QImageIOHandler::CompressionRatio)){
+			writer.setQuality(quality);
+			writer.setCompression(compression);
+			writer.write(image);
+		} else
+			image.save(fileName, 0, quality);
+	}
 }
 
 #if QT_VERSION >= 0x040500
@@ -2297,9 +2315,9 @@ void Graph3D::exportVector(const QString& fileName, int textExportMode, int sort
 
 void Graph3D::exportToFile(const QString& fileName)
 {
-	if ( fileName.isEmpty() ){
+	if (fileName.isEmpty()){
 		QMessageBox::critical(this, tr("QtiPlot - Error"), tr("Please provide a valid file name!"));
-        return;
+		return;
 	}
 
 	if (fileName.contains(".eps") || fileName.contains(".pdf") ||
@@ -2308,13 +2326,13 @@ void Graph3D::exportToFile(const QString& fileName)
 		return;
 	} else {
 		QList<QByteArray> list = QImageWriter::supportedImageFormats();
-    	for(int i=0 ; i<list.count() ; i++){
+		for(int i = 0; i < list.count(); i++){
 			if (fileName.contains( "." + list[i].toLower())){
 				exportImage(fileName);
 				return;
 			}
 		}
-    	QMessageBox::critical(this, tr("QtiPlot - Error"), tr("File format not handled, operation aborted!"));
+		QMessageBox::critical(this, tr("QtiPlot - Error"), tr("File format not handled, operation aborted!"));
 	}
 }
 
@@ -2762,7 +2780,7 @@ void Graph3D::save(const QString &fn, const QString &geometry, bool)
 	t << "WindowLabel\t" + windowLabel() + "\t" + QString::number(captionPolicy()) + "\n";
 	t << "Orthogonal\t" + QString::number(sp->ortho())+"\n";
 	if (d_color_map_file.isEmpty())
-		t << ColorMapEditor::saveToXmlString(d_color_map);
+		t << d_color_map.toXmlString();
 
 	t << "axisType\t" << scaleType[0] << "\t" << scaleType[1] << "\t" << scaleType[2] << "\n";
 
@@ -2867,7 +2885,7 @@ void Graph3D::setOptions(bool legend, int r, int dist)
 	setLabelsDistance(dist);
 }
 
-void Graph3D::setDataColorMap(const QwtLinearColorMap& colorMap)
+void Graph3D::setDataColorMap(const LinearColorMap& colorMap)
 {
 	if (!d_active_curve)
 		return;
@@ -2875,31 +2893,28 @@ void Graph3D::setDataColorMap(const QwtLinearColorMap& colorMap)
 	d_color_map = colorMap;
 	d_color_map_file = QString::null;
 
-	double zmin, zmax;
-	sp->coordinates()->axes[Z1].limits (zmin, zmax);
-	const QwtDoubleInterval intensityRange = QwtDoubleInterval(zmin, zmax);
+	double zmin = d_active_curve->hull().minVertex.z;
+	double zmax = d_active_curve->hull().maxVertex.z;
+	const QwtDoubleInterval range = colorMap.intensityRange().isValid() ? colorMap.intensityRange() : QwtDoubleInterval(zmin, zmax);
 
 	int size = 255;
 	double dsize = size;
 	double dz = fabs(zmax - zmin)/dsize;
 	Qwt3D::ColorVector cv;
 	for (int i = 0; i < size; i++){
-		QRgb color = colorMap.rgb(intensityRange, zmin + i*dz);
+		QRgb color = colorMap.rgb(range, zmin + i*dz);
 		RGBA rgb(qRed(color)/dsize, qGreen(color)/dsize, qBlue(color)/dsize, d_alpha);
 		cv.push_back(rgb);
 	}
 
-	col_ = new StandardColor(d_active_curve);
+	col_ = new StandardColor(d_active_curve, size);
 	col_->setColorVector(cv);
 	d_active_curve->setDataColor(col_);
 
-	if (legendOn){
-		sp->showColorLegend(false);
-		sp->showColorLegend(legendOn);
-	}
+	sp->showColorLegend(legendOn);
 }
 
-void Graph3D::setDataColorMap(const ColorVector& colors, const QwtLinearColorMap& colorMap)
+void Graph3D::setDataColorMap(const ColorVector& colors, const LinearColorMap& colorMap)
 {
 	d_color_map = colorMap;
 	d_color_map_file = QString::null;
@@ -3382,26 +3397,16 @@ Graph3D* Graph3D::restore(ApplicationWindow* app, const QStringList &lst, int fi
 		plot->update();
 		return plot;
 	}
-	QString s = line.next().stripWhiteSpace();
-	int mode = s.remove("<Mode>").remove("</Mode>").stripWhiteSpace().toInt();
-	s = line.next();
-	QColor color1 = QColor(s.remove("<MinColor>").remove("</MinColor>").stripWhiteSpace());
-	s = line.next();
-	QColor color2 = QColor(s.remove("<MaxColor>").remove("</MaxColor>").stripWhiteSpace());
 
-	QwtLinearColorMap colorMap = QwtLinearColorMap(color1, color2);
-	colorMap.setMode((QwtLinearColorMap::Mode)mode);
-
-	s = line.next();
-	int stops = s.remove("<ColorStops>").remove("</ColorStops>").stripWhiteSpace().toInt();
-	for (int i = 0; i < stops; i++){
-		s = line.next().stripWhiteSpace();
-		QStringList l = QStringList::split("\t", s.remove("<Stop>").remove("</Stop>"));
-		colorMap.addColorStop(l[0].toDouble(), QColor(l[1]));
+	QStringList aux;
+	QString s = line.next();
+	while (s != "</ColorMap>" ){
+		aux << s;
+		s = line.next();
 	}
-	plot->setDataColorMap(colorMap);
+	aux.pop_back();
+	plot->setDataColorMap(LinearColorMap::fromXmlStringList(aux));
 
-	line.next();
 	s = line.next();
 
 	fList = s.split("\t", QString::SkipEmptyParts);
@@ -3417,6 +3422,7 @@ Graph3D* Graph3D::restore(ApplicationWindow* app, const QStringList &lst, int fi
 		s = line.next();
 		if (s == "<Grid>" && line.hasNext()){
 			s = line.next().stripWhiteSpace();
+
 			if (s.contains("<Major>")){
 				fList = s.remove("<Major>").remove("</Major>").split("\t", QString::SkipEmptyParts);
 				if (fList.size() == 4){
@@ -3428,6 +3434,7 @@ Graph3D* Graph3D::restore(ApplicationWindow* app, const QStringList &lst, int fi
 
 			if (line.hasNext())
 				s = line.next().stripWhiteSpace();
+
 			if (s.contains("<Minor>")){
 				fList = s.remove("<Minor>").remove("</Minor>").split("\t", QString::SkipEmptyParts);
 				if (fList.size() == 4){
