@@ -125,6 +125,7 @@ private:
 	QSpinBox *boxMajors, *boxMinors;
 	QGroupBox *TicksGroupBox, *AxesColorGroupBox;
 	QSpinBox *boxResolution, *boxDistance, *boxTransparency;
+	QSlider *transparencySlider;
 	QCheckBox *boxLegend, *boxSmooth, *boxBoxed, *boxCrossSmooth, *boxOrthogonal;
 	QListWidget *axesList, *axesList2;
 	QComboBox *boxType, *boxPointStyle;
@@ -140,6 +141,7 @@ private:
 	DoubleSpinBox *boxMajorGridWidth, *boxMinorGridWidth;
 	QComboBox *boxMajorGridStyle, *boxMinorGridStyle, *boxTickLabelsFormat;
 	QCheckBox *boxMajorGrids, *boxMinorGrids;
+	DoubleSpinBox *boxXRotation, *boxYRotation, *boxZRotation;
 };
 
 #endif
