@@ -31,6 +31,7 @@
 #include <MyParser.h>
 #include <ApplicationWindow.h>
 #include <DoubleSpinBox.h>
+#include <ScriptEdit.h>
 
 #include <QMessageBox>
 #include <QLayout>
@@ -44,6 +45,7 @@
 #include <QStackedWidget>
 #include <QCompleter>
 #include <QApplication>
+#include <QInputDialog>
 
 SurfaceDialog::SurfaceDialog( QWidget* parent, Qt::WFlags fl )
     : QDialog( parent, fl )
@@ -65,7 +67,7 @@ SurfaceDialog::SurfaceDialog( QWidget* parent, Qt::WFlags fl )
 	initFunctionPage();
 	initParametricSurfacePage();
 
-	buttonClear = new QPushButton(tr("Clear &list"));
+	buttonClear = new QPushButton(tr("Clea&r"));
 	buttonOk = new QPushButton(tr("&OK"));
     buttonOk->setDefault(true);
     buttonCancel = new QPushButton(tr("&Close"));
@@ -81,39 +83,40 @@ SurfaceDialog::SurfaceDialog( QWidget* parent, Qt::WFlags fl )
 	vl->addWidget(optionStack);
 	vl->addLayout(bl2);
 
-	ApplicationWindow *app = (ApplicationWindow *)parent;
-	if (app){
-		boxFunction->insertItems(0, app->surfaceFunc);
-		boxX->setCompleter (new QCompleter(app->d_param_surface_func));
-		boxY->setCompleter (new QCompleter(app->d_param_surface_func));
-		boxZ->setCompleter (new QCompleter(app->d_param_surface_func));
-	}
-
 	d_graph = 0;
     setFocusProxy(boxFunction);
 
 	connect( boxType, SIGNAL(activated(int)), optionStack, SLOT(setCurrentIndex(int)));
-	connect( buttonClear, SIGNAL(clicked()), this, SLOT(clearList()));
+	connect( buttonClear, SIGNAL(clicked()), this, SLOT(clearFunction()));
     connect( buttonOk, SIGNAL(clicked()), this, SLOT(accept()));
     connect( buttonCancel, SIGNAL(clicked()), this, SLOT(reject()));
 }
 
 void SurfaceDialog::initFunctionPage()
 {
-	boxFunction = new QComboBox();
-	boxFunction->setEditable(true);
+	ApplicationWindow *app = (ApplicationWindow *)parent();
+	QLocale locale = QLocale();
+
+	boxFunction = new ScriptEdit(app->scriptingEnv());
+	boxFunction->enableShortcuts();
+	boxFunction->setFocus();
 
 	QBoxLayout *bl1 = new QBoxLayout (QBoxLayout::LeftToRight);
-	bl1->addWidget(new QLabel( tr("f(x,y)=")), 1);
+
+	QVBoxLayout *vl1 = new QVBoxLayout();
+	vl1->addWidget(new QLabel( tr("f(x,y)=")));
+
+	buttonRecentFunc = new QPushButton(tr("Rece&nt"));
+	buttonRecentFunc->setToolTip(tr("Click here to select a recently typed expression"));
+	connect(buttonRecentFunc, SIGNAL(clicked()), this, SLOT(showFunctionLog()));
+	vl1->addWidget(buttonRecentFunc);
+	vl1->addStretch();
+
+	bl1->addLayout(vl1, 1);
 	bl1->addWidget(boxFunction, 10);
 
     QGroupBox *gb1 = new QGroupBox(tr("X - axis"));
 
-	ApplicationWindow *app = (ApplicationWindow *)parent();
-	QLocale locale = QLocale();
-	if (app)
-		locale = app->locale();
-
 	boxXFrom = new DoubleSpinBox();
 	boxXFrom->setLocale(locale);
 
@@ -127,6 +130,7 @@ void SurfaceDialog::initFunctionPage()
     gl1->addWidget(new QLabel(tr("To")), 1, 0);
     gl1->addWidget(boxXTo, 1, 1);
     gl1->setRowStretch(2, 1);
+	gl1->setColumnStretch(1, 10);
     gb1->setLayout(gl1);
 
     QGroupBox *gb2 = new QGroupBox(tr("Y - axis"));
@@ -142,6 +146,7 @@ void SurfaceDialog::initFunctionPage()
     gl2->addWidget(new QLabel(tr("To")), 1, 0);
     gl2->addWidget(boxYTo, 1, 1);
     gl2->setRowStretch(2, 1);
+	gl2->setColumnStretch(1, 10);
     gb2->setLayout(gl2);
 
     QGroupBox *gb3 = new QGroupBox(tr("Z - axis"));
@@ -157,6 +162,7 @@ void SurfaceDialog::initFunctionPage()
     gl3->addWidget(new QLabel(tr("To")), 1, 0);
     gl3->addWidget(boxZTo, 1, 1);
     gl3->setRowStretch(2, 1);
+	gl3->setColumnStretch(1, 10);
     gb3->setLayout(gl3);
 
 	QBoxLayout *bl2 = new QBoxLayout (QBoxLayout::LeftToRight);
@@ -182,34 +188,76 @@ void SurfaceDialog::initFunctionPage()
 	functionPage = new QWidget();
 
 	QVBoxLayout* vl = new QVBoxLayout(functionPage);
-    vl->addLayout(bl1);
+	vl->addLayout(bl1);
 	vl->addLayout(bl2);
 	vl->addWidget(gb4);
+	vl->addStretch();
 
 	optionStack->addWidget(functionPage);
 }
 
 void SurfaceDialog::initParametricSurfacePage()
 {
-	boxX = new QLineEdit();
-	boxY = new QLineEdit();
-	boxZ = new QLineEdit();
+	ApplicationWindow *app = (ApplicationWindow *)parent();
+	QLocale locale = QLocale();
+	int prec = 6;
+	if (app)
+		prec = app->d_decimal_digits;
+
+	int maxH = 80;
+	boxX = new ScriptEdit(app->scriptingEnv());
+	boxX->setMaximumHeight(maxH);
+	boxX->enableShortcuts();
+
+	boxY = new ScriptEdit(app->scriptingEnv());
+	boxY->setMaximumHeight(maxH);
+	boxY->enableShortcuts();
+
+	boxZ = new ScriptEdit(app->scriptingEnv());
+	boxZ->setMaximumHeight(maxH);
+	boxZ->enableShortcuts();
+
+	QString recentTip = tr("Click here to select a recently typed expression");
+	QString recentBtnText = tr("Rece&nt");
+
+	buttonXLog = new QPushButton(recentBtnText);
+	buttonXLog->setToolTip(recentTip);
+	connect(buttonXLog, SIGNAL(clicked()), this, SLOT(showXLog()));
+
+	buttonYLog = new QPushButton(recentBtnText);
+	buttonYLog->setToolTip(recentTip);
+	connect(buttonYLog, SIGNAL(clicked()), this, SLOT(showYLog()));
+
+	buttonZLog = new QPushButton(recentBtnText);
+	buttonZLog->setToolTip(recentTip);
+	connect(buttonZLog, SIGNAL(clicked()), this, SLOT(showZLog()));
 
 	QGroupBox *gb = new QGroupBox(tr("Equations"));
 	QGridLayout *gl = new QGridLayout(gb);
     gl->addWidget(new QLabel( tr("X(u,v)=")), 0, 0);
     gl->addWidget(boxX, 0, 1);
+	gl->addWidget(buttonXLog, 0, 2);
+
     gl->addWidget(new QLabel(tr("Y(u,v)=")), 1, 0);
     gl->addWidget(boxY, 1, 1);
+	gl->addWidget(buttonYLog, 1, 2);
+
 	gl->addWidget(new QLabel(tr("Z(u,v)=")), 2, 0);
     gl->addWidget(boxZ, 2, 1);
+	gl->addWidget(buttonZLog, 2, 2);
+
     gl->setRowStretch(3, 1);
 
     QGroupBox *gb1 = new QGroupBox(tr("u"));
-	boxUFrom = new QLineEdit();
-	boxUFrom->setText("0");
-	boxUTo = new QLineEdit();
-	boxUTo->setText("pi");
+	boxUFrom = new DoubleSpinBox();
+	boxUFrom->setDecimals(prec);
+	boxUFrom->setLocale(locale);
+
+	boxUTo = new DoubleSpinBox();
+	boxUTo->setLocale(locale);
+	boxUTo->setDecimals(prec);
+	boxUTo->setValue(M_PI);
+
     QGridLayout *gl1 = new QGridLayout();
     gl1->addWidget(new QLabel( tr("From")), 0, 0);
     gl1->addWidget(boxUFrom, 0, 1);
@@ -218,14 +266,18 @@ void SurfaceDialog::initParametricSurfacePage()
 	boxUPeriodic = new QCheckBox(tr("Periodic"));
 	gl1->addWidget(boxUPeriodic, 2, 1);
     gl1->setRowStretch(3, 1);
+	gl1->setColumnStretch(1, 10);
     gb1->setLayout(gl1);
 
     QGroupBox *gb2 = new QGroupBox(tr("v"));
-	boxVFrom = new QLineEdit();
-	boxVFrom->setText("0");
+	boxVFrom = new DoubleSpinBox();
+	boxVFrom->setDecimals(prec);
+	boxVFrom->setLocale(locale);
 
-	boxVTo = new QLineEdit();
-	boxVTo->setText("pi");
+	boxVTo = new DoubleSpinBox();
+	boxVTo->setLocale(locale);
+	boxVTo->setDecimals(prec);
+	boxVTo->setValue(M_PI);
 
     QGridLayout *gl2 = new QGridLayout();
     gl2->addWidget(new QLabel( tr("From")), 0, 0);
@@ -235,6 +287,7 @@ void SurfaceDialog::initParametricSurfacePage()
 	boxVPeriodic = new QCheckBox(tr("Periodic"));
 	gl2->addWidget(boxVPeriodic, 2, 1);
     gl2->setRowStretch(3, 1);
+	gl2->setColumnStretch(1, 10);
     gb2->setLayout(gl2);
 
 	QGroupBox *gb3 = new QGroupBox(tr("Mesh"));
@@ -268,17 +321,14 @@ void SurfaceDialog::initParametricSurfacePage()
 	optionStack->addWidget(parametricPage);
 }
 
-void SurfaceDialog::clearList()
+void SurfaceDialog::clearFunction()
 {
-    ApplicationWindow *app = (ApplicationWindow *)this->parent();
-
-    if (app && boxType->currentIndex())
-        app->d_param_surface_func.clear();
-    else {
-        boxFunction->clear();
-        if (app)
-            app->clearSurfaceFunctionsList();
-    }
+	if (boxType->currentIndex()){
+		boxX->clear();
+		boxY->clear();
+		boxZ->clear();
+	} else
+		boxFunction->clear();
 }
 
 void SurfaceDialog::setFunction(Graph3D *g)
@@ -291,7 +341,7 @@ void SurfaceDialog::setFunction(Graph3D *g)
 	if (!f)
 		return;
 
-	boxFunction->setCurrentText(f->function());
+	boxFunction->setText(f->function());
 	boxFuncColumns->setValue(f->columns());
 	boxFuncRows->setValue(f->rows());
 	boxXFrom->setValue(g->xStart());
@@ -320,7 +370,7 @@ void SurfaceDialog::acceptParametricSurface()
 	parser.DefineVar("v", &v);
 
     int list_size = 15;
-    QString x_formula = boxX->text();
+	QString x_formula = boxX->text().simplified();
 	try {
 		parser.SetExpr(x_formula.ascii());
 		parser.Eval();
@@ -335,7 +385,7 @@ void SurfaceDialog::acceptParametricSurface()
 	while ((int)app->d_param_surface_func.size() > list_size)
 		app->d_param_surface_func.pop_back();
 
-    QString y_formula = boxY->text();
+	QString y_formula = boxY->text().simplified();
 	try {
 		parser.SetExpr(y_formula.ascii());
 		parser.Eval();
@@ -350,7 +400,7 @@ void SurfaceDialog::acceptParametricSurface()
 	while ((int)app->d_param_surface_func.size() > list_size)
 		app->d_param_surface_func.pop_back();
 
-    QString z_formula = boxZ->text();
+	QString z_formula = boxZ->text().simplified();
 	try {
 		parser.SetExpr(z_formula.ascii());
 		parser.Eval();
@@ -365,50 +415,10 @@ void SurfaceDialog::acceptParametricSurface()
 	while ((int)app->d_param_surface_func.size() > list_size)
 		app->d_param_surface_func.pop_back();
 
-	QString ufrom = boxUFrom->text().lower();
-	QString uto = boxUTo->text().lower();
-	QString vfrom = boxVFrom->text().lower();
-	QString vto = boxVTo->text().lower();
-	double ul, ur, vl, vr;
-	try{
-		parser.SetExpr(ufrom.ascii());
-		ul = parser.Eval();
-	}
-	catch(mu::ParserError &e){
-		QMessageBox::critical(app, tr("QtiPlot - u start limit error"), QString::fromStdString(e.GetMsg()));
-		boxUFrom->setFocus();
-		return;
-	}
-
-	try{
-		parser.SetExpr(uto.ascii());
-		ur = parser.Eval();
-	}
-	catch(mu::ParserError &e){
-		QMessageBox::critical(app, tr("QtiPlot - u end limit error"), QString::fromStdString(e.GetMsg()));
-		boxUTo->setFocus();
-		return;
-	}
-
-	try{
-		parser.SetExpr(vfrom.ascii());
-		vl = parser.Eval();
-	}
-	catch(mu::ParserError &e){
-		QMessageBox::critical(app, tr("QtiPlot - v start limit error"), QString::fromStdString(e.GetMsg()));
-		boxVFrom->setFocus();
-		return;
-	}
-
-	try{
-		parser.SetExpr(vto.ascii());
-		vr = parser.Eval();
-	}
-	catch(mu::ParserError &e){
-		QMessageBox::critical(app, tr("QtiPlot - u end limit error"), QString::fromStdString(e.GetMsg()));
-		boxVTo->setFocus();
-		return;
-	}
+	double ul = boxUFrom->value();
+	double ur = boxUTo->value();
+	double vl = boxVFrom->value();
+	double vr = boxVTo->value();
 
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 	if (!d_graph)
@@ -441,7 +451,7 @@ void SurfaceDialog::acceptFunction()
 		return;
 	}
 
-	QString formula = boxFunction->currentText();
+	QString formula = boxFunction->text().simplified();
 	bool error = false;
 	try{
 		MyParser parser;
@@ -463,13 +473,13 @@ void SurfaceDialog::acceptFunction()
 	if (!error){
 		QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 		if (!d_graph)
-			app->plotSurface(boxFunction->currentText(), fromX, toX, fromY, toY, fromZ, toZ,
+			app->plotSurface(formula, fromX, toX, fromY, toY, fromZ, toZ,
 						 boxFuncColumns->value(), boxFuncRows->value());
 		else
-			d_graph->addFunction(boxFunction->currentText(),fromX, toX, fromY, toY, fromZ, toZ,
+			d_graph->addFunction(formula,fromX, toX, fromY, toY, fromZ, toZ,
 						 boxFuncColumns->value(), boxFuncRows->value());
 
-		app->updateSurfaceFuncList(boxFunction->currentText());
+		app->updateSurfaceFuncList(formula);
 		QApplication::restoreOverrideCursor();
 		close();
 	}
@@ -490,10 +500,10 @@ void SurfaceDialog::setParametricSurface(Graph3D *g)
 	boxY->setText(s->yFormula());
 	boxZ->setText(s->zFormula());
 
-	boxUFrom->setText(QString::number(s->uStart()));
-	boxUTo->setText(QString::number(s->uEnd()));
-	boxVFrom->setText(QString::number(s->vStart()));
-	boxVTo->setText(QString::number(s->vEnd()));
+	boxUFrom->setValue(s->uStart());
+	boxUTo->setValue(s->uEnd());
+	boxVFrom->setValue(s->vStart());
+	boxVTo->setValue(s->vEnd());
 
 	boxColumns->setValue(s->columns());
 	boxRows->setValue(s->rows());
@@ -501,3 +511,71 @@ void SurfaceDialog::setParametricSurface(Graph3D *g)
 	boxUPeriodic->setChecked(s->uPeriodic());
 	boxVPeriodic->setChecked(s->vPeriodic());
 }
+
+void SurfaceDialog::showFunctionLog()
+{
+	ApplicationWindow *app = (ApplicationWindow *)this->parent();
+	if (!app)
+		return;
+
+	if (app->surfaceFunc.isEmpty()){
+		QMessageBox::information(this, tr("QtiPlot"), tr("Sorry, there are no recent expressions available!"));
+		return;
+	}
+
+	bool ok;
+	QString s = QInputDialog::getItem(this, tr("QtiPlot") + " - " + tr("Recent Functions"), tr("Please, choose a function:"), app->surfaceFunc, 0, false, &ok);
+	if (ok && !s.isEmpty())
+		boxFunction->setText(s);
+}
+
+void SurfaceDialog::showXLog()
+{
+	ApplicationWindow *app = (ApplicationWindow *)this->parent();
+	if (!app)
+		return;
+
+	if (app->d_param_surface_func.isEmpty()){
+		QMessageBox::information(this, tr("QtiPlot"), tr("Sorry, there are no recent expressions available!"));
+		return;
+	}
+
+	bool ok;
+	QString s = QInputDialog::getItem(this, tr("QtiPlot") + " - " + tr("Recent Functions"), tr("Please, choose a function:"), app->d_param_surface_func, 0, false, &ok);
+	if (ok && !s.isEmpty())
+		boxX->setText(s);
+}
+
+void SurfaceDialog::showYLog()
+{
+	ApplicationWindow *app = (ApplicationWindow *)this->parent();
+	if (!app)
+		return;
+
+	if (app->d_param_surface_func.isEmpty()){
+		QMessageBox::information(this, tr("QtiPlot"), tr("Sorry, there are no recent expressions available!"));
+		return;
+	}
+
+	bool ok;
+	QString s = QInputDialog::getItem(this, tr("QtiPlot") + " - " + tr("Recent Functions"), tr("Please, choose a function:"), app->d_param_surface_func, 0, false, &ok);
+	if (ok && !s.isEmpty())
+		boxY->setText(s);
+}
+
+void SurfaceDialog::showZLog()
+{
+	ApplicationWindow *app = (ApplicationWindow *)this->parent();
+	if (!app)
+		return;
+	
+	if (app->d_param_surface_func.isEmpty()){
+		QMessageBox::information(this, tr("QtiPlot"), tr("Sorry, there are no recent expressions available!"));
+		return;
+	}
+
+	bool ok;
+	QString s = QInputDialog::getItem(this, tr("QtiPlot") + " - " + tr("Recent Functions"), tr("Please, choose a function:"), app->d_param_surface_func, 0, false, &ok);
+	if (ok && !s.isEmpty())
+		boxZ->setText(s);
+}
