@@ -32,7 +32,6 @@
 
 #include <QMessageBox>
 #include <QApplication>
-#include <QSettings>
 #include <QLocale>
 
 #include <gsl/gsl_const_mksa.h>
@@ -55,20 +54,25 @@ MyParser::MyParser()
 	}
 	gsl_set_error_handler_off();
 
-#ifdef Q_OS_MAC
-	QSettings settings(QSettings::IniFormat,QSettings::UserScope, "ProIndependent", "QtiPlot");
-#else
-	QSettings settings(QSettings::NativeFormat,QSettings::UserScope, "ProIndependent", "QtiPlot");
-#endif
-	settings.beginGroup("/General");
-	bool cLocale = settings.value("/MuParserCLocale", true).toBool();
-	settings.endGroup();
+	setLocale(getLocale());
+}
+
+QLocale MyParser::getLocale()
+{
+	bool cLocale = true;
+	foreach (QWidget *w, QApplication::allWidgets()){
+		ApplicationWindow *app = qobject_cast<ApplicationWindow *>(w);
+		if (app){
+			cLocale = app->d_muparser_c_locale;
+			break;
+		}
+	}
 
 	QLocale locale = QLocale::c();
 	if (!cLocale)
 		locale = QLocale();
 
-	setLocale(locale);
+	return locale;
 }
 
 void MyParser::setLocale(const QLocale& locale)
@@ -106,7 +110,7 @@ const QStringList MyParser::functionsList()
   QStringList l;
 
   QString argSeparator = ",";
-  if (QString(QLocale().decimalPoint()) == argSeparator)
+  if (QString(getLocale().decimalPoint()) == argSeparator)
 	argSeparator = ";";
 
   for (const muParserScripting::mathFunction *i = muParserScripting::math_functions; i->name; i++){
@@ -131,7 +135,7 @@ QString MyParser::explainFunction(int index)
 {
 	const muParserScripting::mathFunction i = muParserScripting::math_functions[index];
 	QString s = QObject::tr(i.description);
-	if (QLocale().decimalPoint() == ',')
+	if (getLocale().decimalPoint() == ',')
 		s.replace(",", ";");
 
 	return s;
