@@ -511,7 +511,7 @@ void ScriptEdit::print(QPrinter *printer)
 QString ScriptEdit::importASCII(const QString &filename)
 {
 	QString filter = scriptEnv->fileFilter();
-	filter += tr("Text") + " (*.txt *.TXT);;";
+	filter += tr("Text") + " (*.txt *.TXT);";
 	filter += tr("All Files")+" (*)";
 
 	QString f;
@@ -559,9 +559,9 @@ QString ScriptEdit::save()
 
 QString ScriptEdit::exportASCII(const QString &filename)
 {
-	QString filter = tr("Text") + " (*.txt *.TXT);;";
-	filter += scriptEnv->fileFilter();
-	filter += tr("All Files")+" (*)";
+	QString filter = scriptEnv->fileFilter();
+	filter += tr("Text") + " (*.txt);";
+	filter += tr("All Files") + " (*)";
 
 	QString selectedFilter;
 	QString fn;
@@ -573,7 +573,6 @@ QString ScriptEdit::exportASCII(const QString &filename)
 	if (!fn.isEmpty()){
 		QFileInfo fi(fn);
 		scriptsDirPath = fi.absolutePath();
-
 		if (selectedFilter.contains(".txt") && !fn.endsWith(".txt", Qt::CaseInsensitive))
 			fn.append(".txt");
 		else if (selectedFilter.contains(".py") && !fn.endsWith(".py", Qt::CaseInsensitive))
