@@ -142,7 +142,8 @@ void ExportDialog::initAdvancedOptions()
 
 void ExportDialog::updateAdvancedOptions (const QString & filter)
 {
-	bool on = !filter.contains(".tex") && !filter.contains(".odf") && !filter.contains(".html") && !filter.contains(".xls");
+	bool on = !filter.contains(".tex") && !filter.contains(".odf") && !filter.contains(".html") &&
+			  !filter.contains(".xls") && !filter.contains(".ods") && !filter.contains(".csv");
 	separatorLbl->setVisible(on);
 	boxSeparator->setVisible(on);
 	buttonHelp->setVisible(on);
@@ -176,14 +177,16 @@ void ExportDialog::enableTableName(bool ok)
 void ExportDialog::setFileTypeFilters()
 {
 	QList<QByteArray> list;
+	list << "CSV";
 	list << "DAT";
-	list << "ODF";
-	list << "HTML";
 	list << "TXT";
 	list << "TEX";
-#ifdef XLS_IMPORT
-	list << "XLS";
+#if QT_VERSION >= 0x040500
+	list << "ODF";
+	list << "HTML";
 #endif
+	list << "ODS";
+	list << "XLS";
 
 	QStringList filters;
 	for(int i = 0 ; i < list.count() ; i++)
@@ -237,11 +240,14 @@ void ExportDialog::accept()
 		}
 		file.close();
 
-		if (d_window->inherits("Table"))
-            ((Table *)d_window)->exportASCII(file_name, sep, boxNames->isChecked(),
-								boxComments->isChecked(), boxSelection->isChecked());
-        else if (d_window->isA("Matrix"))
-            ((Matrix *)d_window)->exportASCII(file_name, sep, boxSelection->isChecked());
+		MdiSubWindow* w = app->window(boxTable->currentText());
+		if (!w)
+			return;
+
+		if (w->inherits("Table"))
+			((Table *)w)->exportASCII(file_name, sep, boxNames->isChecked(), boxComments->isChecked(), boxSelection->isChecked());
+		else if (qobject_cast<Matrix *>(w))
+			((Matrix *)w)->exportASCII(file_name, sep, boxSelection->isChecked());
 	}
 
 	close();
